@@ -13,33 +13,19 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.
 */
 
-#include <KoApplication.h>
-#include <KoDocument.h>
-#include <KoMainWindow.h>
-#include <kcmdlineargs.h>
-#include <klocale.h>
-#include <dcopclient.h>
-#include "example_aboutdata.h"
-#include <koffice_export.h>
+#include <koApplication.h>
+#include <koDocument.h>
+#include <koMainWindow.h>
+#include <koQueryTypes.h>
 
-static const KCmdLineOptions options[]=
+int main( int argc, char **argv )
 {
-	{"+[file]", I18N_NOOP("File to open"),0},
-	KCmdLineLastOption
-};
-
-extern "C" EXAMPLE_EXPORT int kdemain( int argc, char **argv )
-{
-    KCmdLineArgs::init( argc, argv, newExampleAboutData() );
-    KCmdLineArgs::addCmdLineOptions( options );
-    KoApplication app;
-
-    if (!app.start()) // parses command line args, create initial docs and shells
-	return 1;
-    return app.exec();
+    KoApplication app( argc, argv, "example", "application/x-example" );
+    app.start(); // parses command line args, create initial docs and shells
+    app.exec();
+    return 0;
 }
-
