@@ -1,6 +1,5 @@
 /* This file is part of the KDE project
    Copyright (C) 1998, 1999 Reginald Stadlbauer <reggie@kde.org>
-   Copyright (C) 2001 Nicolas GOUTTE <nicog@snafu.de>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -26,8 +25,11 @@
 #include <qfile.h>
 #include <qobject.h>
 
+#include <kdebug.h>
 #include <koFilter.h>
-#include <koStore.h>
+#include <koTarStore.h>
+
+#include <kword_xml2html.h>
 
 
 class HTMLExport : public KoFilter {
@@ -35,12 +37,11 @@ class HTMLExport : public KoFilter {
     Q_OBJECT
 
 public:
-    HTMLExport(KoFilter *parent, const char *name);
+    HTMLExport(KoFilter *parent, QString name);
     virtual ~HTMLExport() {}
     /** filtering :) */
-    virtual bool filter(const QString &fileIn, const QString &fileOut,
-                        const QString &from, const QString &to,
-                        const QString &config=QString::null);
-};
+    virtual const bool filter(const QCString &fileIn, const QCString &fileOut,
+                              const QCString& from, const QCString& to);
 
-#endif // HTMLEXPORT_H
+};
+#endif // HTMLExport_H
