@@ -1,39 +1,14 @@
-/* This file is part of the KDE project
-   Copyright (C) 1999 Matthias Kalle Dalheimer <kalle@kde.org>
-
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
-*/
+/*
+ * $Id: kchartColorConfigPage.h,v 1.2 1999/11/17 21:02:34 kalle Exp $
+ *
+ * Copyright 1999 by Kalle Dalheimer, released under Artistic License.
+ */
 
 #ifndef __KCHARTCOLORCONFIGPAGE_H__
 #define __KCHARTCOLORCONFIGPAGE_H__
 
-
 #include <qwidget.h>
-#include <kcolorbutton.h>
-
-#include "koChart.h"
-#include "kchartcolorarray.h"
-
-class KListBox;
-
-
-namespace KChart
-{
-
-class KChartParams;
+#include <kcolorbtn.h>
 
 // PENDING(kalle) Make this dynamic.
 #define NUMDATACOLORS 6
@@ -43,8 +18,7 @@ class KChartColorConfigPage : public QWidget
     Q_OBJECT
 
 public:
-    KChartColorConfigPage( KChartParams* params, QWidget* parent, KoChart::Data *dat );
-    void apply();
+    KChartColorConfigPage( QWidget* parent );
 
     void setBackgroundColor( QColor color );
     QColor backgroundColor() const;
@@ -52,60 +26,59 @@ public:
     QColor gridColor() const;
     void setLineColor( QColor color );
     QColor lineColor() const;
+    void setPlotColor( QColor color );
+    QColor plotColor() const;
+    void setVolColor( QColor color );
+    QColor volColor() const;
     void setTitleColor( QColor color );
     QColor titleColor() const;
     void setXTitleColor( QColor color );
     QColor xTitleColor() const;
     void setYTitleColor( QColor color );
     QColor yTitleColor() const;
-#if 0
     void setYTitle2Color( QColor color );
     QColor yTitle2Color() const;
-#endif
     void setXLabelColor( QColor color );
     QColor xLabelColor() const;
     void setYLabelColor( QColor color );
     QColor yLabelColor() const;
-#if 0
     void setYLabel2Color( QColor color );
     QColor yLabel2Color() const;
-#endif
-    /*void setEdgeColor( QColor color );
-    QColor edgeColor() const;*/
+    void setEdgeColor( QColor color );
+    QColor edgeColor() const;
 /*     void setDataColor( uint dataset, QColor color ); */
 /*     QColor dataColor( uint dataset ) const; */
 
-private slots:
-    void activeColorButton();
-    void changeIndex( int );
-
 private:
-    void initDataColorList();
-
-    KChartParams   *m_params;
-    KoChart::Data  *m_data;
-
-    KColorButton* _lineCB;
+    KColorButton* _backgroundCB;
     KColorButton* _gridCB;
+    KColorButton* _lineCB;
+    KColorButton* _plotCB;
+    KColorButton* _volCB;
+    KColorButton* _titleCB;
     KColorButton* _xtitleCB;
     KColorButton* _ytitleCB;
-#if 0
     KColorButton* _ytitle2CB;
-#endif
     KColorButton* _xlabelCB;
     KColorButton* _ylabelCB;
-#if 0
     KColorButton* _ylabel2CB;
-#endif
-    //KColorButton* _edgeCB;
+    KColorButton* _edgeCB;
 //    KColorButton* _dataCB[NUMDATACOLORS];
-    KListBox* _dataColorLB;
-    KColorButton* _dataColorCB;
-    KChartColorArray extColor;
-    uint index;
 };
 
 
+inline void KChartColorConfigPage::setBackgroundColor( QColor color )
+{
+    _backgroundCB->setColor( color );
+}
+
+
+inline QColor KChartColorConfigPage::backgroundColor() const
+{
+    return _backgroundCB->color();
+}
+
+
 inline void KChartColorConfigPage::setGridColor( QColor color )
 {
     _gridCB->setColor( color );
@@ -130,6 +103,42 @@ inline QColor KChartColorConfigPage::lineColor() const
 }
 
 
+inline void KChartColorConfigPage::setPlotColor( QColor color )
+{
+    _plotCB->setColor( color );
+}
+
+
+inline QColor KChartColorConfigPage::plotColor() const
+{
+    return _plotCB->color();
+}
+
+
+inline void KChartColorConfigPage::setVolColor( QColor color )
+{
+    _volCB->setColor( color );
+}
+
+
+inline QColor KChartColorConfigPage::volColor() const
+{
+    return _volCB->color();
+}
+
+
+inline void KChartColorConfigPage::setTitleColor( QColor color )
+{
+    _titleCB->setColor( color );
+}
+
+
+inline QColor KChartColorConfigPage::titleColor() const
+{
+    return _titleCB->color();
+}
+
+
 inline void KChartColorConfigPage::setXTitleColor( QColor color )
 {
     _xtitleCB->setColor( color );
@@ -154,7 +163,6 @@ inline QColor KChartColorConfigPage::yTitleColor() const
 }
 
 
-#if 0
 inline void KChartColorConfigPage::setYTitle2Color( QColor color )
 {
     _ytitle2CB->setColor( color );
@@ -165,7 +173,7 @@ inline QColor KChartColorConfigPage::yTitle2Color() const
 {
     return _ytitle2CB->color();
 }
-#endif
+
 
 inline void KChartColorConfigPage::setXLabelColor( QColor color )
 {
@@ -191,7 +199,6 @@ inline QColor KChartColorConfigPage::yLabelColor() const
 }
 
 
-#if 0
 inline void KChartColorConfigPage::setYLabel2Color( QColor color )
 {
     _ylabel2CB->setColor( color );
@@ -202,9 +209,9 @@ inline QColor KChartColorConfigPage::yLabel2Color() const
 {
     return _ylabel2CB->color();
 }
-#endif
 
-/*inline void KChartColorConfigPage::setEdgeColor( QColor color )
+
+inline void KChartColorConfigPage::setEdgeColor( QColor color )
 {
     _edgeCB->setColor( color );
 }
@@ -213,8 +220,7 @@ inline QColor KChartColorConfigPage::yLabel2Color() const
 inline QColor KChartColorConfigPage::edgeColor() const
 {
     return _edgeCB->color();
-}*/
+}
 
-}  //KChart namespace
 
 #endif
