@@ -18,32 +18,13 @@
 */
 
 #include <koApplication.h>
-#include <kcmdlineargs.h>
-#include <klocale.h>
-#include "kchart_aboutdata.h"
 
-using namespace KChart;
-
-namespace KChart
+int main( int argc, char **argv )
 {
+    KoApplication app( argc, argv, "kchart", "application/x-kchart" );
 
-static const KCmdLineOptions options[]=
-{
-	{"+[file]", I18N_NOOP("File to open"),0},
-	KCmdLineLastOption
-};
+    app.start();
 
-}  //namespace KChart
-
-
-extern "C" KCHART_EXPORT int kdemain( int argc, char **argv )
-{
-    KCmdLineArgs::init( argc, argv, newKChartAboutData());
-    KCmdLineArgs::addCmdLineOptions( options );
-
-    KoApplication app;
-    if (!app.start())
-	return 1;
     app.exec();
 
     return 0;
