@@ -1,4 +1,6 @@
 /****************************************************************************
+** $Id: parser.h,v 1.4 1999/10/20 10:07:37 kulow Exp $
+**
 ** Copyright (C) 1992-1998 Troll Tech AS.  All rights reserved.
 **
 ** This file is part of an example program for Qt.  This example
@@ -28,7 +30,7 @@ public:
     double  doubleVal( int row, int col );
     int  intVal( int row, int col ) { return (int) doubleVal(row,col); }
 
-
+    
     QString     rawText( int row, int col );
     void        setText( int row, int col, QString ); //shallow copy
 
@@ -46,7 +48,7 @@ private:
     Data *current;
     short index; // opt: later const char *
 
-    QChar get_c();
+    char get_c();
     void putback();
 
     Type parseExpr( double & );
@@ -55,9 +57,9 @@ private:
     Type parseRef( double & );
     Type parseNumber( double & );
     Type parseInt( int & );
-
+    
     int idx( int r, int c ) const { return c+r*numCols; }
-    bool isValid( int r, int c ) const
+    bool isValid( int r, int c ) const 
     { return (uint) r < (uint) numRows && (uint) c < (uint) numCols; } //Ugle
 };
 
