@@ -1,4 +1,3 @@
-// -*- Mode: c++; c-basic-offset: 4; indent-tabs-mode: nil; tab-width: 4; -*-
 /* This file is part of the KDE project
    Copyright (C) 1998, 1999 Reginald Stadlbauer <reggie@kde.org>
 
@@ -21,28 +20,21 @@
 #ifndef KPRESENTER_FACTORY_H
 #define KPRESENTER_FACTORY_H
 
-#include <koFactory.h>
-class KAboutData;
+#include <klibloader.h>
 
-class KPresenterFactory : public KoFactory
+class KPresenterFactory : public KLibFactory
 {
     Q_OBJECT
 public:
     KPresenterFactory( QObject* parent = 0, const char* name = 0 );
     ~KPresenterFactory();
 
-    virtual KParts::Part *createPartObject( QWidget *parentWidget = 0, const char *widgetName = 0, QObject *parent = 0,
-                                            const char *name = 0, const char *classname = "KoDocument",
-                                            const QStringList &args = QStringList() );
+    virtual QObject* create( QObject* parent = 0, const char* name = 0, const char* classname = "QObject", const QStringList &args = QStringList() );
 
     static KInstance* global();
 
-    // _Creates_ a KAboutData but doesn't keep ownership
-    static KAboutData* aboutData();
-
 private:
     static KInstance* s_global;
-    static KAboutData* s_aboutData;
 };
 
 #endif
