@@ -17,30 +17,30 @@
    Boston, MA 02111-1307, USA.
 */
 
-#include "kpresenter_aboutdata.h"
+#include "kpresenter_doc.h"
+#include "kpresenter_shell.h"
 
 #include <koApplication.h>
 
 #include <dcopclient.h>
-#include <kcmdlineargs.h>
-#include <klocale.h>
 
-
-static const KCmdLineOptions options[]=
+extern "C"
 {
-	{"+[file]", I18N_NOOP("File to open"),0},
-	KCmdLineLastOption
-};
+    void* init_libkpresenter();
+}
 
-extern "C" KPRESENTER_EXPORT int kdemain( int argc, char **argv )
+int main( int argc, char **argv )
 {
-    KCmdLineArgs::init( argc, argv, newKPresenterAboutData() );
-    KCmdLineArgs::addCmdLineOptions( options );
+    KoApplication app( argc, argv, "kpresenter", "application/x-kpresenter" );
 
-    KoApplication app;
+    init_libkpresenter();
+	
+    app.dcopClient()->attach();
+    app.dcopClient()->registerAs( "kpresenter" );
 
-    if (!app.start())
-        return 1;
+    app.start();
 
-    return app.exec();
+    app.exec();
+
+    return 0;
 }
