@@ -17,10 +17,13 @@
    Boston, MA 02111-1307, USA.
 */
 
-#include <webpresentation.h>
+#include "webpresentation.h"
+#include "webpresentation.moc"
 
-#include <kpresenter_view.h>
-#include <page.h>
+#include "kpresenter_doc.h"
+#include "kpresenter_view.h"
+#include "page.h"
+#include "preview.h"
 
 #include <stdlib.h>
 #include <unistd.h>
@@ -31,6 +34,7 @@
 #include <qtextstream.h>
 #include <qvbox.h>
 #include <qhbox.h>
+#include <qpalette.h>
 #include <qlabel.h>
 #include <qpushbutton.h>
 #include <qcombobox.h>
@@ -38,36 +42,31 @@
 #include <qlineedit.h>
 #include <qlistview.h>
 #include <qfileinfo.h>
+#include <qevent.h>
 #include <qframe.h>
+#include <kprogress.h>
 #include <qfont.h>
 #include <qpixmap.h>
+#include <qsize.h>
 #include <qdatetime.h>
+#include <qmessagebox.h>
 #include <qdir.h>
 #include <qheader.h>
 #include <qwmatrix.h>
+#include <qfiledialog.h>
 
-#include <kdebug.h>
 #include <klocale.h>
-#include <kcolorbutton.h>
+#include <kcolorbtn.h>
 #include <kfiledialog.h>
-#include <kmessagebox.h>
 #include <kbuttonbox.h>
 #include <ksimpleconfig.h>
-#include <kimageio.h>
-#include <kapp.h>
-#include <kprogress.h>
+#include <kimgio.h>
+
 #include <kstddirs.h>
 #include <kglobal.h>
-#include <kglobalsettings.h>
-#include <kcharsets.h>
-#include <kurlrequester.h>
-#include <klineedit.h>
-#include <kfiledialog.h>
-
-#include "koDocumentInfo.h"
 
 /******************************************************************/
-/* Class: KPWebPresentation                                       */
+/* Class: KPWebPresentation					  */
 /******************************************************************/
 
 /*================================================================*/
@@ -92,7 +91,7 @@ KPWebPresentation::KPWebPresentation( const QString &_config, KPresenterDoc *_do
 /*================================================================*/
 KPWebPresentation::KPWebPresentation( const KPWebPresentation &webPres )
     : config( webPres.config ), author( webPres.author ), title( webPres.title ), email( webPres.email ),
-      slideInfos( webPres.slideInfos ), backColor( webPres.backColor ), titleColor( webPres.titleColor ),
+      slideTitles( webPres.slideTitles ), backColor( webPres.backColor ), titleColor( webPres.titleColor ),
       textColor( webPres.textColor ), path( webPres.path ), imgFormat( webPres.imgFormat ), zoom( webPres.zoom )
 {
     doc = webPres.doc;
@@ -103,7 +102,7 @@ KPWebPresentation::KPWebPresentation( const KPWebPresentation &webPres )
 void KPWebPresentation::loadConfig()
 {
     if ( config.isEmpty() )
-        return;
+	return;
 
     KSimpleConfig cfg( config );
     cfg.setGroup( "General" );
@@ -111,20 +110,11 @@ void KPWebPresentation::loadConfig()
     author = cfg.readEntry( "Author", author );
     title = cfg.readEntry( "Title", title );
     email = cfg.readEntry( "EMail", email );
-    unsigned int num = cfg.readNumEntry( "Slides", slideInfos.count() );
-    //kdDebug(33001) << "KPWebPresentation::loadConfig num=" << num << endl;
+    unsigned int num = cfg.readNumEntry( "Slides", doc->getPageNums() );
 
-    if ( num <= slideInfos.count() ) {
-        for ( unsigned int i = 0; i < num; i++ )
-        {
-            QString key = QString::fromLatin1( "SlideTitle%1" ).arg( i );
-            if ( cfg.hasKey( key ) )
-            {
-                // We'll assume that the selected pages haven't changed... Hmm.
-                slideInfos[ i ].slideTitle = cfg.readEntry( key );
-                kdDebug(33001) << "KPWebPresentation::loadConfig key=" << key << " data=" << slideInfos[i].slideTitle << endl;
-            } else kdDebug(33001) << " key not found " << key << endl;
-        }
+    if ( num <= doc->getPageNums() ) {
+	for ( unsigned int i = 0; i < num; i++ )
+	    slideTitles[ i ] = cfg.readEntry( QString( "SlideTitle[%1]" ).arg( i ), slideTitles[ i ] );
     }
 
     backColor = cfg.readColorEntry( "BackColor", &backColor );
@@ -144,10 +134,10 @@ void KPWebPresentation::saveConfig()
     cfg.writeEntry( "Author", author );
     cfg.writeEntry( "Title", title );
     cfg.writeEntry( "EMail", email );
-    cfg.writeEntry( "Slides", slideInfos.count() );
+    cfg.writeEntry( "Slides", doc->getPageNums() );
 
-    for ( unsigned int i = 0; i < slideInfos.count(); i++ )
-        cfg.writeEntry( QString::fromLatin1( "SlideTitle%1" ).arg( i ), slideInfos[ i ].slideTitle );
+    for ( unsigned int i = 0; i < doc->getPageNums(); i++ )
+	cfg.writeEntry( QString( "SlideTitle[ %1 ]" ).arg( i ), slideTitles[ i ] );
 
     cfg.writeEntry( "BackColor", backColor );
     cfg.writeEntry( "TitleColor", titleColor );
@@ -183,42 +173,42 @@ void KPWebPresentation::initCreation( KProgress *progressBar )
     QString filename;
 
     while ( pics[ index ] ) {
-        filename = pics[index] + format;
-        system( QFile::encodeName( QString( "cp %1 %2/pics/%3" ).
-                arg( locate( "slideshow", filename, KPresenterFactory::global() ) ).
-                arg( path ).arg( filename ) ) );
-        p = progressBar->value();
-        progressBar->setValue( ++p );
-        kapp->processEvents();
-        index++;
+	filename = pics[index] + format;
+	system( QString( "cp %1 %2/pics/%3" ).
+		arg( locate( "appdata", "slideshow/" + filename ) ).
+		arg( path ).arg( filename ) );
+	p = progressBar->value();
+	progressBar->setValue( ++p );
+	kapp->processEvents();
+	index++;
     }
 }
 
 /*================================================================*/
 void KPWebPresentation::createSlidesPictures( KProgress *progressBar )
 {
-    QPixmap pix( QSize( doc->getPageRect( 0, 0, 0, 1.0, false ).width(),
-                        doc->getPageRect( 0, 0, 0, 1.0, false ).height() ) );
+    QPixmap pix( QSize( doc->getPageSize( 0, 0, 0, 1.0, FALSE ).width(),
+			doc->getPageSize( 0, 0, 0, 1.0, FALSE ).height() ) );
     QString filename;
     QString format = imageFormat( imgFormat );
     int p;
 
-    for ( unsigned int i = 0; i < slideInfos.count(); i++ ) {
-        pix.resize( doc->getPageRect( 0, 0, 0, 1.0, false ).size() );
-        pix.fill( Qt::white );
-        int pgNum = slideInfos[i].pageNumber;
-        view->getPage()->drawPageInPix2( pix, pgNum * doc->getPageRect( 0, 0, 0, 1.0, false ).height(), pgNum );
-        filename = QString( "%1/pics/slide_%2.%3" ).arg( path ).arg( i + 1 ).arg( format );
-        if ( zoom != 100 ) {
-            QWMatrix m;
-            m.scale( ( (float)zoom ) / 100.0, ( (float)zoom ) / 100.0 );
-            pix = pix.xForm( m ); // maybe we should use smoothScale ?
-        }
-        pix.save( filename, format.upper().latin1() );   //lukas: provide the option to choose image quality
+    for ( unsigned int i = 0; i < doc->getPageNums(); i++ ) {
+	pix.resize( QSize( doc->getPageSize( 0, 0, 0, 1.0, FALSE ).width(),
+			   doc->getPageSize( 0, 0, 0, 1.0, FALSE ).height() ) );
+	pix.fill( Qt::white );
+	view->getPage()->drawPageInPix2( pix, i * doc->getPageSize( 0, 0, 0, 1.0, FALSE ).height(), i );
+	filename = QString( "%1/pics/slide_%2.%3" ).arg( path ).arg( i + 1 ).arg( format );
+	if ( zoom != 100 ) {
+	    QWMatrix m;
+	    m.scale( ( (float)zoom ) / 100.0, ( (float)zoom ) / 100.0 );
+	    pix = pix.xForm( m );
+	}
+	pix.save( filename, format.upper() );
 
-        p = progressBar->value();
-        progressBar->setValue( ++p );
-        kapp->processEvents();
+	p = progressBar->value();
+	progressBar->setValue( ++p );
+	kapp->processEvents();
     }
 }
 
@@ -229,100 +219,90 @@ void KPWebPresentation::createSlidesHTML( KProgress *progressBar )
     int p;
     QString format = imageFormat( imgFormat );
 
-    QFont::CharSet chset = KGlobal::charsets()->charsetForLocale();
-    QString chsetName = KGlobal::charsets()->name(chset);
-
     QString html;
-    for ( unsigned int i = 0; i < slideInfos.count(); i++ ) {
-        pgNum = i + 1;
-        html = QString( "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0 Transitional//EN\">" );
-        html += QString( "<HTML><HEAD><TITLE>%1 - %2</TITLE>\n" ).arg( title ).arg( slideInfos[ i ].slideTitle );
+    for ( unsigned int i = 0; i < doc->getPageNums(); i++ ) {
+	pgNum = i + 1;
+	html = QString( "<HTML><HEAD><TITLE>%1 - %2</TITLE></HEAD>\n" ).arg( title ).arg( slideTitles[ i ] );
 
-        html += QString( "<META HTTP-Equiv=\"Content-Type\" CONTENT=\"text/html; charset=%1\">\n" )
-            .arg( chsetName );
+	QString c1;
+	c1.sprintf( "%02X%02X%02X", backColor.red(), backColor.green(), backColor.blue() );
+	QString c2;
+	c2.sprintf( "%02X%02X%02X", textColor.red(), textColor.green(), textColor.blue() );
+	QString c3;
+	c3.sprintf( "%02X%02X%02X", titleColor.red(), titleColor.green(), titleColor.blue() );
 
-        html += QString( "</HEAD>\n" );
-        html += QString( "<BODY bgcolor=\"%1\" text=\"%2\">\n" ).arg( backColor.name() ).arg( textColor.name() );
+	html += QString( "<BODY bgcolor=\"%1\" text=\"%2\">\n" ).arg( c1 ).arg( c2 );
 
-        html += QString( "  <CENTER>\n" );
-        if ( i > 0 )
-            html += QString( "    <A HREF=\"slide_1.html\">" );
-        html += QString( "<IMG src=\"../pics/first.%1\" border=\"0\">" ).arg( format );
-        if ( i > 0 )
-            html += "</A>\n";
-        else
-            html += "\n";
+	html += QString( "  <CENTER>\n" );
+	if ( i > 0 )
+	    html += QString( "	  <A HREF=\"slide_1.html\">" );
+	html += QString( "<IMG src=\"../pics/first.%1\" border=\"0\">" ).arg( format );
+	if ( i > 0 )
+	    html += "</A>\n";
+	else
+	    html += "\n";
 
-        if ( i > 0 )
-            html += QString( "    <A HREF=\"slide_%1.html\">" ).arg( pgNum - 1 );
-        html += QString( "<IMG src=\"../pics/prev.%1\" border=\"0\">" ).arg( format );
-        if ( i > 0 )
-            html += "</A>\n";
-        else
-            html += "\n";
+	if ( i > 0 )
+	    html += QString( "	  <A HREF=\"slide_%1.html\">" ).arg( pgNum - 1 );
+	html += QString( "<IMG src=\"../pics/prev.%1\" border=\"0\">" ).arg( format );
+	if ( i > 0 )
+	    html += "</A>\n";
+	else
+	    html += "\n";
 
-        if ( i < slideInfos.count() - 1 )
-            html += QString( "    <A HREF=\"slide_%1.html\">" ).arg( pgNum + 1 );
-        html += QString( "<IMG src=\"../pics/next.%1\" border=\"0\">" ).arg( format );
-        if ( i < slideInfos.count() - 1 )
-            html += "</A>\n";
-        else
-            html += "\n";
+	if ( i < doc->getPageNums() - 1 )
+	    html += QString( "	  <A HREF=\"slide_%1.html\">" ).arg( pgNum + 1 );
+	html += QString( "<IMG src=\"../pics/next.%1\" border=\"0\">" ).arg( format );
+	if ( i < doc->getPageNums() - 1 )
+	    html += "</A>\n";
+	else
+	    html += "\n";
 
-        if ( i < slideInfos.count() - 1 )
-            html += QString( "    <A HREF=\"slide_%1.html\">" ).arg( slideInfos.count() );
-        html += QString( "<IMG src=\"../pics/last.%1\" border=\"0\">" ).arg( format );
-        if ( i < slideInfos.count() - 1 )
-            html += "</A>\n";
-        else
-            html += "\n";
+	if ( i < doc->getPageNums() - 1 )
+	    html += QString( "	  <A HREF=\"slide_%1.html\">" ).arg( doc->getPageNums() );
+	html += QString( "<IMG src=\"../pics/last.%1\" border=\"0\">" ).arg( format );
+	if ( i < doc->getPageNums() - 1 )
+	    html += "</A>\n";
+	else
+	    html += "\n";
 
-        html += "    &nbsp; &nbsp; &nbsp; &nbsp; \n";
+	html += "    &nbsp; &nbsp; &nbsp; &nbsp; \n";
 
-        html += "    <A HREF=\"../index.html\">";
-        html += QString( "<IMG src=\"../pics/home.%1\" border=\"0\">" ).arg( format );
-        html += "</A>\n";
+	html += "    <A HREF=\"../index.html\">";
+	html += QString( "<IMG src=\"../pics/home.%1\" border=\"0\">" ).arg( format );
+	html += "</A>\n";
 
-        html += "  </CENTER><BR><HR noshade>\n";
+	html += "  </CENTER><BR><HR noshade>\n";
 
-        html += QString( "  <FONT color=\"%1\">\n" ).arg( titleColor.name() );
-        html += QString( "  <CENTER><B>%1</B> - <I>%2</I></CENTER>\n" ).arg( title ).arg( slideInfos[ i ].slideTitle );
+	html += QString( "  <FONT color=\"%1\">\n" ).arg( c3 );
+	html += QString( "  <CENTER><B>%1</B> - <I>%2</I></CENTER>\n" ).arg( title ).arg( slideTitles[ i ] );
 
-        html += "  </FONT><HR noshade><BR>\n";
+	html += "  </FONT><HR noshade><BR>\n";
 
-        html += "  <CENTER>\n";
+	html += "  <CENTER>\n";
+	html += QString( "    <IMG src=\"../pics/slide_%1.%2\">" ).arg( pgNum ).arg( format );
+	html += "  </CENTER><BR><HR noshade>\n";
+	html += "  <CENTER>\n";
+	html += "    <B>Author: </B>";
+	if ( !email.isEmpty() )
+	    html += QString( "<A HREF=\"mailto:%1\">" ).arg( email );
+	html += QString( "<I>%1</I>" ).arg( author );
+	if ( !email.isEmpty() )
+	    html += "</A>";
 
-        html += "    ";
-        if ( i < slideInfos.count() - 1 )
-            html += QString( "<A HREF=\"slide_%1.html\">" ).arg( pgNum + 1 );
-        html += QString( "<IMG src=\"../pics/slide_%1.%2\" BORDER=0>" ).arg( pgNum ).arg( format );
-        if ( i < slideInfos.count() - 1 )
-            html += "</A>\n";
-        else
-            html += "\n";
+	html += " - created with <A HREF=\"http://koffice.kde.org/kpresenter.html\">KPresenter</A>\n";
+	html += "  </CENTER><HR noshade>\n";
+	html += "</BODY></HTML>\n";
 
-        html += "  </CENTER><BR><HR noshade>\n";
-        html += "  <CENTER>\n";
-        html += "    <B>"+ i18n("Author:") + " </B>";
-        if ( !email.isEmpty() )
-            html += QString( "<A HREF=\"mailto:%1\">" ).arg( email );
-        html += QString( "<I>%1</I>" ).arg( author );
-        if ( !email.isEmpty() )
-            html += "</A>";
+	QFile file( QString( "%1/html/slide_%2.html" ).arg( path ).arg( pgNum ) );
+	file.open( IO_WriteOnly );
+	QTextStream t( &file );
+	t << html;
+	file.close();
 
-        html += i18n(" - created with %1").arg("<A HREF=\"http://www.koffice.org/kpresenter/\">KPresenter</A>");
-        html += "  </CENTER><HR noshade>\n";
-        html += "</BODY></HTML>\n";
-
-        QFile file( QString( "%1/html/slide_%2.html" ).arg( path ).arg( pgNum ) );
-        file.open( IO_WriteOnly );
-        QTextStream t( &file );
-        t << html;
-        file.close();
-
-        p = progressBar->value();
-        progressBar->setValue( ++p );
-        kapp->processEvents();
+	p = progressBar->value();
+	progressBar->setValue( ++p );
+	kapp->processEvents();
     }
 }
 
@@ -331,43 +311,35 @@ void KPWebPresentation::createMainPage( KProgress *progressBar )
 {
     QString html;
 
-    QFont::CharSet chset = KGlobal::charsets()->charsetForLocale();
-    QString chsetName = KGlobal::charsets()->name(chset);
+    html = QString( "<HTML><HEAD><TITLE>%1 - Table of Contents</TITLE></HEAD>\n" ).arg( title );
 
-    html = QString( "<HTML><HEAD><TITLE>%1 - ").arg( title );
-    html += i18n("Table of Contents");
-    html += "</TITLE>\n";
-    html += QString( "<META HTTP-Equiv=\"Content-Type\" CONTENT=\"text/html; charset=%1\">\n" )
-            .arg( chsetName );
-    html += "</HEAD>\n";
+    QString c1;
+    c1.sprintf( "%02X%02X%02X", backColor.red(), backColor.green(), backColor.blue() );
+    QString c2;
+    c2.sprintf( "%02X%02X%02X", textColor.red(), textColor.green(), textColor.blue() );
+    QString c3;
+    c3.sprintf( "%02X%02X%02X", titleColor.red(), titleColor.green(), titleColor.blue() );
 
-    html += QString( "<BODY bgcolor=\"%1\" text=\"%2\">\n" ).arg( backColor.name() ).arg( textColor.name() );
+    html += QString( "<BODY bgcolor=\"%1\" text=\"%2\">\n" ).arg( c1 ).arg( c2 );
 
-    html += QString( "<FONT color=\"%1\">\n" ).arg( titleColor.name() );
+    html += QString( "<FONT color=\"%1\">\n" ).arg( c3 );
     html += QString( "<BR><CENTER><H1>%1</H1></CENTER>\n" ).arg( title );
     html += "</FONT>\n";
 
-    html += "<BR><BR><CENTER><H3><A HREF=\"html/slide_1.html\">";
-    html += i18n("Click here to start the Slideshow");
-    html += "</A></H3></CENTER><BR>\n";
+    html += "<BR><BR><CENTER><H3><A HREF=\"html/slide_1.html\">Click here to start the Slideshow</A></H3></CENTER><BR>\n";
 
     html += "<HR noshade><BR><BR>\n";
 
     if ( email.isEmpty() )
-        html += i18n( "Created on %1 by <I>%2</I>" ).
-	  arg( KGlobal::locale()->formatDate ( QDate::currentDate() ) ).
-	  arg( author );
+	html += QString( "Created on %1 by <I>%2</I><BR><BR>\n" ).arg( QDate::currentDate().toString() ).arg( author );
     else
-        html += i18n( "Created on %1 by <I><A HREF=\"mailto:%2\">%3</A></I>" ).
-	  arg( KGlobal::locale()->formatDate ( QDate::currentDate() ) ).
-	  arg( email ).
-	  arg( author );
+	html += QString( "Created on %1 by <I><A HREF=\"mailto:%2\">%3</A></I><BR><BR>\n" ).arg( QDate::currentDate().toString() ).arg( email ).arg( author );
 
-    html += "<BR><BR>\n<B>" + i18n("Table of Contents") + "</B><BR>\n";
+    html += "<B>Table of Contents</B><BR>\n";
     html += "<OL>\n";
 
-    for ( unsigned int i = 0; i < slideInfos.count(); i++ )
-        html += QString( "  <LI><A HREF=\"html/slide_%1.html\">%2</A><BR>\n" ).arg( i + 1 ).arg( slideInfos[ i ].slideTitle );
+    for ( unsigned int i = 0; i < doc->getPageNums(); i++ )
+	html += QString( "  <LI><A HREF=\"html/slide_%1.html\">%2</A><BR>\n" ).arg( i + 1 ).arg( slideTitles[ i ] );
 
     html += "</OL></BODY></HTML>\n";
 
@@ -384,51 +356,49 @@ void KPWebPresentation::createMainPage( KProgress *progressBar )
 /*================================================================*/
 void KPWebPresentation::init()
 {
+    struct passwd* pw;
+    char str[ 80 ];
 
-    KoDocumentInfo * info = doc->documentInfo();
-    KoDocumentInfoAuthor * authorPage = static_cast<KoDocumentInfoAuthor *>(info->page( "author" ));
-    if ( !authorPage )
-        kdWarning() << "Author information not found in documentInfo !" << endl;
-    else
-    {
-        author = authorPage->fullName();
-        email = authorPage->email();
+    pw = getpwuid( getuid() );
+    if ( pw ) {
+	author = QString( pw->pw_gecos );
+	int i = author.find( ',' );
+	if ( i > 0 ) author.truncate( i );
     }
 
-    title = i18n("Slideshow");
+    pw = getpwuid( getuid() );
+    if ( pw ) {
+	gethostname( str, 79 );
+	email = QString( pw->pw_name ) + "@" + str;
+    }
+
+    title = "Slideshow";
 
     for ( unsigned int i = 0; i < doc->getPageNums(); i++ )
-    {
-        if ( doc->isSlideSelected( i ) )
-        {
-            SlideInfo info;
-            info.pageNumber = i;
-            info.slideTitle = doc->getPageTitle( i, i18n( "Slide %1" ).arg( i+1 ) );
-            slideInfos.append( info );
-        }
-    }
+	slideTitles.append( doc->getPageTitle( i, QString( "Slide %1" ).arg( i ) ) );
 
     backColor = Qt::white;
     textColor = Qt::black;
     titleColor = Qt::red;
     if (KImageIO::canWrite("JPEG"))
-        imgFormat = JPEG;
+	imgFormat = JPEG;
     else
-        imgFormat = PNG;
+	imgFormat = PNG;
 
-    path = KGlobalSettings::documentPath() + "www";
+    path = getenv( "HOME" );
+    path += "/www";
 
     zoom = 100;
 }
 
 /******************************************************************/
-/* Class: KPWebPresentationWizard                                 */
+/* Class: KPWebPresentationWizard				  */
 /******************************************************************/
 
 /*================================================================*/
 KPWebPresentationWizard::KPWebPresentationWizard( const QString &_config, KPresenterDoc *_doc,
-                                                  KPresenterView *_view )
-    : QWizard( 0, "", false ), config( _config ), webPres( config, _doc, _view )
+						  KPresenterView *_view )
+    : QWizard( 0, "", FALSE ), config( _config ), webPres( config, _doc, _view )
 {
     doc = _doc;
     view = _view;
@@ -450,11 +420,11 @@ KPWebPresentationWizard::~KPWebPresentationWizard()
 
 /*================================================================*/
 void KPWebPresentationWizard::createWebPresentation( const QString &_config, KPresenterDoc *_doc,
-                                                     KPresenterView *_view )
+						     KPresenterView *_view )
 {
     KPWebPresentationWizard *dlg = new KPWebPresentationWizard( _config, _doc, _view );
 
-    dlg->setCaption( i18n( "Create HTML Slideshow" ) );
+    dlg->setCaption( i18n( "Create Web-Presentation (HTML Slideshow)" ) );
     dlg->resize( 640, 350 );
     dlg->show();
 }
@@ -469,11 +439,12 @@ void KPWebPresentationWizard::setupPage1()
     QLabel *helptext = new QLabel( page1 );
     helptext->setMargin( 5 );
     helptext->setBackgroundMode( PaletteLight );
-    helptext->setText( i18n( "Enter your name, email address and\n"
-                             "the title of the web presentation.\n"
-                             "Also enter the path into which the\n"
-                             "web presentation should be created\n"
-                             "(This must be a directory).\n" ) );
+    helptext->setText( i18n( "Enter here your Name, your Email\n"
+			     "Address and the Title of the Web-\n"
+			     "Presentation. Also enter the Path\n"
+			     "into which the Web-Presentation\n"
+			     "should be created. This must be a\n"
+			     "directory." ) );
     helptext->setMaximumWidth( helptext->sizeHint().width() );
 
     QVBox *canvas = new QVBox( page1 );
@@ -483,31 +454,36 @@ void KPWebPresentationWizard::setupPage1()
     QHBox *row3 = new QHBox( canvas );
     QHBox *row4 = new QHBox( canvas );
 
-    QLabel *label1 = new QLabel( i18n(" Author: "), row1 );
+    QLabel *label1 = new QLabel( " Author: ", row1 );
     label1->setAlignment( Qt::AlignVCenter );
-    QLabel *label2 = new QLabel( i18n(" Title: "), row2 );
+    QLabel *label2 = new QLabel( " Title: ", row2 );
     label2->setAlignment( Qt::AlignVCenter );
-    QLabel *label3 = new QLabel( i18n(" Email Address: "), row3 );
+    QLabel *label3 = new QLabel( " Email-Address: ", row3 );
     label3->setAlignment( Qt::AlignVCenter );
-    QLabel *label4 = new QLabel( i18n(" Path: "), row4 );
+    QLabel *label4 = new QLabel( " Path: ", row4 );
     label4->setAlignment( Qt::AlignVCenter );
 
+    label1->setMinimumWidth( label3->sizeHint().width() );
+    label2->setMinimumWidth( label3->sizeHint().width() );
+    label3->setMinimumWidth( label3->sizeHint().width() );
+    label4->setMinimumWidth( label3->sizeHint().width() );
+    label1->setMaximumWidth( label3->sizeHint().width() );
+    label2->setMaximumWidth( label3->sizeHint().width() );
+    label3->setMaximumWidth( label3->sizeHint().width() );
+    label4->setMaximumWidth( label3->sizeHint().width() );
+
     author = new QLineEdit( webPres.getAuthor(), row1 );
     title = new QLineEdit( webPres.getTitle(), row2 );
     email = new QLineEdit( webPres.getEmail(), row3 );
 
-    path=new KURLRequester( row4 );
-    path->fileDialog()->setMode( KFile::Directory);
-    path->lineEdit()->setText(webPres.getPath());
-    connect(path, SIGNAL(textChanged(const QString&)),
-           this,SLOT(slotChoosePath(const QString&)));
-    connect(path, SIGNAL(urlSelected( const QString& )),
-           this,SLOT(slotChoosePath(const QString&)));
+    QHBox *hbox = new QHBox( row4 );
+    path = new QLineEdit( webPres.getPath(), hbox );
+    choosePath = new QPushButton( "Choose...", hbox );
+    choosePath->setMaximumSize( choosePath->sizeHint() );
 
     addPage( page1, i18n( "General Information" ) );
 
-    setHelpEnabled(page1, false);  //doesn't do anything currently
-
+    connect( choosePath, SIGNAL( clicked() ), this, SLOT( slotChoosePath() ) );
 }
 
 /*================================================================*/
@@ -521,24 +497,24 @@ void KPWebPresentationWizard::setupPage2()
     helptext->setMargin( 5 );
     helptext->setBackgroundMode( PaletteLight );
     QString help = i18n("Here you can configure the style\n"
-                        "of the web pages (colors). You also\n"
-                        "need to specify the picture format\n"
-                        "which should be used for the slides.\n"
-                        "PNG is a very optimized and well\n"
-                        "compressed format, but may not be\n"
-                        "supported by some old web browsers.\n"
-                        "BMP is a picture format with a bad\n"
-                        "compression, but is supported by\n"
-                        "old web browsers.\n");
+			"of the webpages ( colors ). You also\n"
+			"need to specify the picture format\n"
+			"which should be used for the slides.\n"
+			"PNG is a very optimized and well\n"
+			"compressed format, but may not be\n"
+			"supported by some old Web-Browsers.\n"
+			"BMP is a picture format with a bad\n"
+			"compression, but is supported also by\n"
+			"old Web-Browsers.\n");
 
     if ( KImageIO::canWrite( "JPEG" ) )
-        help += i18n("JPEG is a picture format with quite a good\n"
-                     "compression and which is supported by\n"
-                     "all web browsers.\n");
+	help += i18n("JPEG is a picture format with a quite good\n"
+		     "compression and which is also supported by\n"
+		     "all Web-Browsers.\n");
 
     help += i18n( "\n"
-                  "Finally you can also specify the zoom\n"
-                  "for the slides." );
+		  "Finally you also can specify the zoom\n"
+		  "for the slides." );
     helptext->setText(help);
     helptext->setMaximumWidth( helptext->sizeHint().width() );
 
@@ -550,25 +526,36 @@ void KPWebPresentationWizard::setupPage2()
     QHBox *row4 = new QHBox( canvas );
     QHBox *row5 = new QHBox( canvas );
 
-    QLabel *label1 = new QLabel( i18n(" Text Color: "), row1 );
+    QLabel *label1 = new QLabel( " Text Color: ", row1 );
     label1->setAlignment( Qt::AlignVCenter );
-    QLabel *label2 = new QLabel( i18n(" Title Color: "), row2 );
+    QLabel *label2 = new QLabel( " Title Color: ", row2 );
     label2->setAlignment( Qt::AlignVCenter );
-    QLabel *label3 = new QLabel( i18n(" Background Color: "), row3 );
+    QLabel *label3 = new QLabel( " Background Color: ", row3 );
     label3->setAlignment( Qt::AlignVCenter );
-    QLabel *label4 = new QLabel( i18n(" Picture Format: "), row4 );
+    QLabel *label4 = new QLabel( " Picture Format: ", row4 );
     label4->setAlignment( Qt::AlignVCenter );
-    QLabel *label5 = new QLabel( i18n(" Zoom: "), row5 );
+    QLabel *label5 = new QLabel( " Zoom: ", row5 );
     label5->setAlignment( Qt::AlignVCenter );
 
+    label1->setMinimumWidth( label3->sizeHint().width() );
+    label2->setMinimumWidth( label3->sizeHint().width() );
+    label3->setMinimumWidth( label3->sizeHint().width() );
+    label4->setMinimumWidth( label3->sizeHint().width() );
+    label5->setMinimumWidth( label3->sizeHint().width() );
+    label1->setMaximumWidth( label3->sizeHint().width() );
+    label2->setMaximumWidth( label3->sizeHint().width() );
+    label3->setMaximumWidth( label3->sizeHint().width() );
+    label4->setMaximumWidth( label3->sizeHint().width() );
+    label5->setMaximumWidth( label3->sizeHint().width() );
+
     textColor = new KColorButton( webPres.getTextColor(), row1 );
     titleColor = new KColorButton( webPres.getTitleColor(), row2 );
     backColor = new KColorButton( webPres.getBackColor(), row3 );
-    format = new QComboBox( false, row4 );
+    format = new QComboBox( FALSE, row4 );
     format->insertItem( "BMP", -1 );
     format->insertItem( "PNG", -1 );
     if ( KImageIO::canWrite( "JPEG" ) )
-        format->insertItem( "JPEG", -1 );
+	format->insertItem( "JPEG", -1 );
     format->setCurrentItem( static_cast<int>( webPres.getImageFormat() ) );
     zoom = new QSpinBox( 1, 1000, 1, row5 );
     zoom->setSuffix( " %" );
@@ -576,8 +563,6 @@ void KPWebPresentationWizard::setupPage2()
     zoom->setMaximumHeight( zoom->sizeHint().height() );
 
     addPage( page2, i18n( "Style" ) );
-
-    setHelpEnabled(page2, false);  //doesn't do anything currently
 }
 
 /*================================================================*/
@@ -591,12 +576,12 @@ void KPWebPresentationWizard::setupPage3()
     helptext->setMargin( 5 );
     helptext->setBackgroundMode( PaletteLight );
     helptext->setText( i18n( "Here you can specify titles for\n"
-                             "each slide. Click on a slide in\n"
-                             "the list and then enter the title\n"
-                             "in the textbox below. If you\n"
-                             "click on a title, the KPresenter\n"
-                             "mainview will scroll to this\n"
-                             "slide, so it can be seen." ) );
+			     "each slide. Click in the list on\n"
+			     "on a slide and then enter in the\n"
+			     "editbox below the title. If you\n"
+			     "click on a title the KPresenter\n"
+			     "mainview scrolls to this slide,\n"
+			     "so that you can see the slide." ) );
     helptext->setMaximumWidth( helptext->sizeHint().width() );
 
     QVBox *canvas = new QVBox( page3 );
@@ -609,29 +594,25 @@ void KPWebPresentationWizard::setupPage3()
 
     slideTitle = new QLineEdit( row );
     connect( slideTitle, SIGNAL( textChanged( const QString & ) ), this,
-             SLOT( slideTitleChanged( const QString & ) ) );
+	     SLOT( slideTitleChanged( const QString & ) ) );
 
     slideTitles = new QListView( canvas );
-    slideTitles->addColumn( i18n( "Slide No." ) );
+    slideTitles->addColumn( i18n( "Slide Nr." ) );
     slideTitles->addColumn( i18n( "Slide Title" ) );
     connect( slideTitles, SIGNAL( selectionChanged( QListViewItem * ) ), this,
-             SLOT( slideTitleChanged( QListViewItem * ) ) );
+	     SLOT( slideTitleChanged( QListViewItem * ) ) );
     slideTitles->setSorting( -1 );
-    slideTitles->header()->setMovingEnabled( false );
+    slideTitles->header()->setMovingEnabled( FALSE );
 
-    QValueList<KPWebPresentation::SlideInfo> infos = webPres.getSlideInfos();
-    for ( int i = infos.count() - 1; i >= 0; --i ) {
-        QListViewItem *item = new QListViewItem( slideTitles );
-        item->setText( 0, QString::number( i + 1 ) );
-        //kdDebug(33001) << "KPWebPresentationWizard::setupPage3 " << infos[ i ].slideTitle << endl;
-        item->setText( 1, infos[ i ].slideTitle );
+    for ( int i = doc->getPageNums() - 1; i >= 0; --i ) {
+	QListViewItem *item = new QListViewItem( slideTitles );
+	item->setText( 0, QString( "%1" ).arg( i + 1 ) );
+	item->setText( 1, (int)webPres.getSlideTitles().count() > i ?
+		       QString( webPres.getSlideTitles()[ i ] ) : QString( "No Title" ) );
     }
 
     addPage( page3, i18n( "Slide Titles" ) );
-
-    setHelpEnabled(page3, false);  //doesn't do anything currently
-
-    setFinish( page3, true );
+    setFinish( page3, TRUE );
 }
 
 
@@ -642,54 +623,73 @@ void KPWebPresentationWizard::finish()
     webPres.setEMail( email->text() );
     webPres.setTitle( title->text() );
 
+    QStringList slides = webPres.getSlideTitles();
     QListViewItemIterator it( slideTitles );
     for ( ; it.current(); ++it )
-        webPres.setSlideTitle( it.current()->text( 0 ).toInt() - 1, it.current()->text( 1 ) );
+	slides[ atoi( it.current()->text( 0 ) ) - 1 ] = QString( it.current()->text( 1 ) );
+    webPres.setSlideTitles( slides );
 
     webPres.setBackColor( backColor->color() );
     webPres.setTitleColor( titleColor->color() );
     webPres.setTextColor( textColor->color() );
     webPres.setImageFormat( static_cast<KPWebPresentation::ImageFormat>( format->currentItem() ) );
-    webPres.setPath( path->lineEdit()->text() );
+    webPres.setPath( path->text() );
     webPres.setZoom( zoom->value() );
 
     close();
     KPWebPresentationCreateDialog::createWebPresentation( doc, view, webPres );
 }
 
+/*================================================================*/
+void KPWebPresentationWizard::slotChoosePath()
+{
+    QFileInfo fi( path->text() );
+    QString url = QString::null;
+    if ( fi.exists() && fi.isDir() )
+	url = path->text();
+
+#ifdef USE_QFD
+    url = QFileDialog::getExistingDirectory( url );
+#else
+    url = KFileDialog::getDirectory( url );
+#endif
+    
+    if ( QFileInfo( url ).exists() && QFileInfo( url ).isDir() )
+	path->setText( url );
+}
 
 /*================================================================*/
 bool KPWebPresentationWizard::isPathValid()
 {
-    QFileInfo fi( path->lineEdit()->text() );
+    QFileInfo fi( path->text() );
 
     if ( fi.exists() && fi.isDir() )
-        return true;
+	return TRUE;
 
-    return false;
+    return FALSE;
 }
 
 /*================================================================*/
 void KPWebPresentationWizard::pageChanged()
 {
     if ( currentPage() != page3 ) {
-        if ( !isPathValid() ) {
-            KMessageBox::error( this,
-                                i18n( "The path you entered is not a valid directory!\n"
-                                      "Please correct this." ),
-                                i18n( "Invalid Path" ) );
-            showPage( page1 );
-            path->setFocus();
-        }
+	if ( !isPathValid() ) {
+	    QMessageBox::critical( 0, i18n( "Invalid Path" ),
+				   i18n( "The path you entered is not a valid directory!\n"
+					 "Please correct this." ),
+				   i18n( "OK" ) );
+	    showPage( page1 );
+	    path->setFocus();
+	}
     } else
-        finishButton()->setEnabled( true );
+	finishButton()->setEnabled( TRUE );
 }
 
 /*================================================================*/
 void KPWebPresentationWizard::slideTitleChanged( const QString &s )
 {
     if ( slideTitles->currentItem() )
-        slideTitles->currentItem()->setText( 1, s );
+	slideTitles->currentItem()->setText( 1, s );
 }
 
 /*================================================================*/
@@ -698,7 +698,7 @@ void KPWebPresentationWizard::slideTitleChanged( QListViewItem *i )
     if ( !i ) return;
 
     slideTitle->setText( i->text( 1 ) );
-    view->skipToPage( i->text( 0 ).toInt() - 1 );
+    view->skipToPage( atoi( i->text( 0 ) ) - 1 );
 }
 
 /*================================================================*/
@@ -708,19 +708,14 @@ void KPWebPresentationWizard::closeEvent( QCloseEvent *e )
     QWizard::closeEvent( e );
 }
 
-void KPWebPresentationWizard::slotChoosePath(const QString &text)
-{
-    webPres.setPath(text);
-}
-
 /******************************************************************/
-/* Class: KPWebPresentationCreateDialog                           */
+/* Class: KPWebPresentationCreateDialog				  */
 /******************************************************************/
 
 /*================================================================*/
 KPWebPresentationCreateDialog::KPWebPresentationCreateDialog( KPresenterDoc *_doc, KPresenterView *_view,
-                                                              const KPWebPresentation &_webPres )
-    : QDialog( 0, "", false ), webPres( _webPres )
+							      const KPWebPresentation &_webPres )
+    : QDialog( 0, "", FALSE ), webPres( _webPres )
 {
     doc = _doc;
     view = _view;
@@ -736,11 +731,11 @@ KPWebPresentationCreateDialog::~KPWebPresentationCreateDialog()
 
 /*================================================================*/
 void KPWebPresentationCreateDialog::createWebPresentation( KPresenterDoc *_doc, KPresenterView *_view,
-                                                           const KPWebPresentation &_webPres )
+							   const KPWebPresentation &_webPres )
 {
     KPWebPresentationCreateDialog *dlg = new KPWebPresentationCreateDialog( _doc, _view, _webPres );
 
-    dlg->setCaption( i18n( "Create HTML Slideshow" ) );
+    dlg->setCaption( i18n( "Create Web-Presentation (HTML Slideshow)" ) );
     dlg->resize( 400, 300 );
     dlg->show();
     dlg->start();
@@ -756,15 +751,15 @@ void KPWebPresentationCreateDialog::start()
     createMainPage();
     setCursor( arrowCursor );
 
-    bDone->setEnabled( true );
-    bSave->setEnabled( true );
+    bDone->setEnabled( TRUE );
+    bSave->setEnabled( TRUE );
 }
 
 /*================================================================*/
 void KPWebPresentationCreateDialog::initCreation()
 {
     QFont f = step1->font(), f2 = step1->font();
-    f.setBold( true );
+    f.setBold( TRUE );
     step1->setFont( f );
 
     progressBar->setValue( 0 );
@@ -780,7 +775,7 @@ void KPWebPresentationCreateDialog::initCreation()
 void KPWebPresentationCreateDialog::createSlidesPictures()
 {
     QFont f = step2->font(), f2 = step2->font();
-    f.setBold( true );
+    f.setBold( TRUE );
     step2->setFont( f );
 
     progressBar->setValue( 0 );
@@ -796,7 +791,7 @@ void KPWebPresentationCreateDialog::createSlidesPictures()
 void KPWebPresentationCreateDialog::createSlidesHTML()
 {
     QFont f = step3->font(), f2 = step3->font();
-    f.setBold( true );
+    f.setBold( TRUE );
     step3->setFont( f );
 
     progressBar->setValue( 0 );
@@ -812,7 +807,7 @@ void KPWebPresentationCreateDialog::createSlidesHTML()
 void KPWebPresentationCreateDialog::createMainPage()
 {
     QFont f = step4->font(), f2 = step4->font();
-    f.setBold( true );
+    f.setBold( TRUE );
     step4->setFont( f );
 
     progressBar->setValue( 0 );
@@ -836,10 +831,10 @@ void KPWebPresentationCreateDialog::setupGUI()
     line->setFrameStyle( QFrame::HLine | QFrame::Sunken );
     line->setMaximumHeight( 20 );
 
-    step1 = new QLabel( i18n( "Initialize (create file structure, etc.)" ), back );
+    step1 = new QLabel( i18n( "Initialize ( create file structure, etc. )" ), back );
     step2 = new QLabel( i18n( "Create Pictures of the Slides" ), back );
     step3 = new QLabel( i18n( "Create HTML pages for the slides" ), back );
-    step4 = new QLabel( i18n( "Create Main Page (Table of Contents)" ), back );
+    step4 = new QLabel( i18n( "Create Main Page ( Table of Contents )" ), back );
 
     line = new QFrame( back );
     line->setFrameStyle( QFrame::HLine | QFrame::Sunken );
@@ -856,8 +851,8 @@ void KPWebPresentationCreateDialog::setupGUI()
     bb->addStretch();
     bDone = bb->addButton( i18n( "Done" ) );
 
-    bSave->setEnabled( false );
-    bDone->setEnabled( false );
+    bSave->setEnabled( FALSE );
+    bDone->setEnabled( FALSE );
 
     connect( bDone, SIGNAL( clicked() ), this, SLOT( accept() ) );
     connect( bSave, SIGNAL( clicked() ), this, SLOT( saveConfig() ) );
@@ -875,27 +870,18 @@ void KPWebPresentationCreateDialog::saveConfig()
 {
     QString filename = webPres.getConfig();
     if ( QFileInfo( filename ).exists() )
-        filename = QFileInfo( filename ).absFilePath();
+	filename = QFileInfo( filename ).absFilePath();
     else
-        filename = QString::null;
-
-    KURL url = KFileDialog::getOpenURL( filename, i18n("*.kpweb|KPresenter Web-Presentation (*.kpweb)") );
-
-    if( url.isEmpty() )
-      return;
-
-    if( !url.isLocalFile() )
-    {
-      KMessageBox::sorry( 0L, i18n( "Only local files are currently supported." ) );
-      return;
-    }
-
-    filename = url.path();
+	filename = QString::null;
 
+#ifdef USE_QFD
+    filename = QFileDialog::getOpenFileName( filename, "KPresenter Web-Presentation (*.kpweb)" );
+#else
+    filename = KFileDialog::getOpenFileName( filename, "*.kpweb|KPresenter Web-Presentation" );
+#endif
+    
     if ( !filename.isEmpty() ) {
-        webPres.setConfig( filename );
-        webPres.saveConfig();
+	webPres.setConfig( filename );
+	webPres.saveConfig();
     }
 }
-
-#include <webpresentation.moc>
