@@ -1,11 +1,11 @@
 #include "KSpreadMapIface.h"
 
 #include "kspread_map.h"
+#include "kspread_table.h"
 #include "kspread_doc.h"
 
-#include <kapplication.h>
+#include <kapp.h>
 #include <dcopclient.h>
-#include <kdebug.h>
 
 KSpreadMapIface::KSpreadMapIface( KSpreadMap* map )
     : DCOPObject( map )
@@ -15,23 +15,23 @@ KSpreadMapIface::KSpreadMapIface( KSpreadMap* map )
 
 DCOPRef KSpreadMapIface::table( const QString& name )
 {
-    KSpreadSheet* t = m_map->findTable( name );
+    KSpreadTable* t = m_map->findTable( name );
     if ( !t )
-        return DCOPRef();
+	return DCOPRef();
 
     return DCOPRef( kapp->dcopClient()->appId(), t->dcopObject()->objId() );
 }
 
-DCOPRef KSpreadMapIface::tableByIndex( int index )
+DCOPRef KSpreadMapIface::table( int index )
 {
-    KSpreadSheet* t = m_map->tableList().at( index );
+    KSpreadTable* t = m_map->tableList().at( index );
     if ( !t )
     {
-        kdDebug(36001) << "+++++ No table found at index " << index << endl;
-        return DCOPRef();
+	qDebug("+++++ No table found at index %i", index );
+	return DCOPRef();
     }
 
-    kdDebug(36001) << "+++++++ Returning table " << t->QObject::name() << endl;
+    qDebug("+++++++ Returning table %s", t->QObject::name() );
 
     return DCOPRef( kapp->dcopClient()->appId(), t->dcopObject()->objId() );
 }
@@ -45,10 +45,10 @@ QStringList KSpreadMapIface::tableNames() const
 {
     QStringList names;
 
-    QPtrList<KSpreadSheet>& lst = m_map->tableList();
-    QPtrListIterator<KSpreadSheet> it( lst );
+    QList<KSpreadTable>& lst = m_map->tableList();
+    QListIterator<KSpreadTable> it( lst );
     for( ; it.current(); ++it )
-        names.append( it.current()->name() );
+	names.append( it.current()->name() );
 
     return names;
 }
@@ -57,10 +57,10 @@ QValueList<DCOPRef> KSpreadMapIface::tables()
 {
     QValueList<DCOPRef> t;
 
-    QPtrList<KSpreadSheet>& lst = m_map->tableList();
-    QPtrListIterator<KSpreadSheet> it( lst );
+    QList<KSpreadTable>& lst = m_map->tableList();
+    QListIterator<KSpreadTable> it( lst );
     for( ; it.current(); ++it )
-        t.append( DCOPRef( kapp->dcopClient()->appId(), it.current()->dcopObject()->objId() ) );
+	t.append( DCOPRef( kapp->dcopClient()->appId(), it.current()->dcopObject()->objId() ) );
 
     return t;
 }
@@ -68,32 +68,32 @@ QValueList<DCOPRef> KSpreadMapIface::tables()
 DCOPRef KSpreadMapIface::insertTable( const QString& name )
 {
     if ( m_map->findTable( name ) )
-        return table( name );
-
-    KSpreadSheet* t = new KSpreadSheet( m_map, name );
+	return table( name );
+    
+    KSpreadTable* t = new KSpreadTable( m_map, name );
     t->setTableName( name );
     m_map->doc()->addTable( t );
-
+    
     return table( name );
 }
 
-bool KSpreadMapIface::processDynamic(const QCString &fun, const QByteArray &/*data*/,
-                                     QCString& replyType, QByteArray &replyData)
+bool KSpreadMapIface::processDynamic(const QCString &fun, const QByteArray &data,
+				     QCString& replyType, QByteArray &replyData)
 {
     // Does the name follow the pattern "foobar()" ?
     uint len = fun.length();
     if ( len < 3 )
-        return FALSE;
-
+	return FALSE;
+    
     if ( fun[ len - 1 ] != ')' || fun[ len - 2 ] != '(' )
-        return FALSE;
-
-    KSpreadSheet* t = m_map->findTable( fun.left( len - 2 ).data() );
+	return FALSE;
+    
+    KSpreadTable* t = m_map->findTable( fun.left( len - 2 ).data() );
     if ( !t )
-        return FALSE;
+	return FALSE;
 
     replyType = "DCOPRef";
     QDataStream out( replyData, IO_WriteOnly );
-    out << DCOPRef( kapp->dcopClient()->appId(), t->dcopObject()->objId() );
+    out << DCOPRef( kapp->dcopClient()->appId(), t->dcopObject()->objId() );    
     return TRUE;
 }
