@@ -1,6 +1,6 @@
 /* This file is part of the KDE project
    Copyright (C) 1998, 1999 Torben Weis <weis@kde.org>
-   Copyright (C) 1999,2000,2001 Montel Laurent <lmontel@mandrakesoft.com>
+   Copyright (C) 1999 Montel Laurent <montell@club-internet.fr>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -22,28 +22,39 @@
 
 #include "kspread_dlg_show.h"
 #include "kspread_view.h"
-#include "kspread_doc.h"
+#include "kspread_canvas.h"
 #include "kspread_tabbar.h"
-#include <qlayout.h>
+#include "kspread_table.h"
+#include <kapp.h>
 #include <klocale.h>
-#include <qlistbox.h>
-#include <qlabel.h>
+#include <qstringlist.h>
+#include <qlayout.h>
+#include <kbuttonbox.h>
+#include <qstrlist.h>
+#include <qlist.h>
+
 
 KSpreadshow::KSpreadshow( KSpreadView* parent, const char* name )
-	: KDialogBase( parent, name,TRUE,i18n("Show Sheet"),Ok|Cancel )
+	: QDialog( 0L, name )
 {
   m_pView = parent;
-  QWidget *page = new QWidget( this );
-  setMainWidget(page);
-  QVBoxLayout *lay1 = new QVBoxLayout( page, 0, spacingHint() );
 
-  QLabel *label = new QLabel( i18n("Select hidden sheets to show:"), page );
-  lay1->addWidget( label );
-
-  list=new QListBox(page);
+  
+  QVBoxLayout *lay1 = new QVBoxLayout( this );
+  lay1->setMargin( 5 );
+  lay1->setSpacing( 10 );
+  list=new QListBox(this);
   lay1->addWidget( list );
 
-  list->setSelectionMode(QListBox::Multi);
+  setCaption( i18n("Table hidden") );
+
+  KButtonBox *bb = new KButtonBox( this );
+  bb->addStretch();
+  m_pOk = bb->addButton( i18n("OK") );
+  m_pOk->setDefault( TRUE );
+  m_pClose = bb->addButton( i18n( "Close" ) );
+  bb->layout();
+  lay1->addWidget( bb );
   QString text;
   QStringList::Iterator it;
   QStringList tabsList=m_pView->tabBar()->listhide();
@@ -52,38 +63,31 @@ KSpreadshow::KSpreadshow( KSpreadView* parent, const char* name )
     	text=*it;
     	list->insertItem(text);
     	}
-  if(!list->count())
-  	enableButtonOK(false);
-  connect( this, SIGNAL( okClicked() ), this, SLOT( slotOk() ) );
-  connect( list, SIGNAL(doubleClicked(QListBoxItem *)),this,SLOT(slotDoubleClicked(QListBoxItem *)));
+
+  connect( m_pOk, SIGNAL( clicked() ), this, SLOT( slotOk() ) );
+  connect( m_pClose, SIGNAL( clicked() ), this, SLOT( slotClose() ) );
   resize( 200, 150 );
-  setFocus();
+  
 }
 
-void KSpreadshow::slotDoubleClicked(QListBoxItem *)
-{
-    slotOk();
-}
 
 
 
 void KSpreadshow::slotOk()
 {
-    m_pView->doc()->emitBeginOperation( false );
-
-    QStringList listTable;
-
-    for (int i=0; i < list->numRows(); i++)
-    {
-        if (list->isSelected(i))
-        {
-            listTable.append( list->text(i));
+  QString text;
+  if(list->currentItem()!=-1)
+	{
+	text=list->text(list->currentItem());
+        m_pView->tabBar()->showTable(text);
         }
-    }
-    m_pView->tabBar()->showTable(listTable);
-
-    m_pView->slotUpdateView( m_pView->activeTable() );
-    accept();
+  accept();
 }
 
+void KSpreadshow::slotClose()
+{
+  reject();
+}
+
+
 #include "kspread_dlg_show.moc"
