@@ -18,28 +18,22 @@
 */
 
 #include <koApplication.h>
-#include <kcmdlineargs.h>
+#include <koDocument.h>
+#include <koMainWindow.h>
+#include <koQueryTypes.h>
+
+#include <kstartparams.h>
 
 #include <dcopclient.h>
-#include "kspread_aboutdata.h"
-
-
-static const KCmdLineOptions options[]=
-{
-	{"+[file]", I18N_NOOP("File to open"),0},
-        KCmdLineLastOption
-};
 
 int main( int argc, char **argv )
 {
+    KoApplication app( argc, argv, "kspread", "application/x-kspread" );
 
-    KCmdLineArgs::init( argc, argv, newKSpreadAboutData() );
-    KCmdLineArgs::addCmdLineOptions( options );
+    app.dcopClient()->attach();
+    app.dcopClient()->registerAs( "kspread" );
 
-    KoApplication app;
-
-    if (!app.start())
-	return 1;
+    app.start();
     app.exec();
     return 0;
 }
