@@ -1,5 +1,5 @@
 /*
-    $Id: kcalc.cpp,v 1.8 2001/07/10 23:16:01 pfeiffer Exp $
+    $Id: kcalc.cpp,v 1.1.1.1 1999/10/20 10:10:32 kulow Exp $
 
     kCalculator, a simple scientific calculator for KDE
 
@@ -25,13 +25,8 @@
 #include "configdlg.h"
 #include "fontdlg.h"
 #include "version.h"
-#include <klocale.h>
-#include <knotifyclient.h>
-#include <qgrid.h>
-#include <qlayout.h>
 
-// What's that?!? (Werner)
-//#define i18n( x ) x
+#define i18n( x ) x
 
 // Undefine HAVE_LONG_DOUBLE for Beta 4 since RedHat 5.0 comes with a borken
 // glibc
@@ -53,22 +48,22 @@ QtCalculator :: QtCalculator( Calculator *_corba, QWidget *parent, const char *n
 
   corba = _corba;
 
-  myxmargin             = 9;
-  myymargin             = 9;
-  bigbuttonwidth        = 30;
-  bigbuttonheight       = 23;
-  smallbuttonwidth      = 30;
-  smallbuttonheight     = 20;
-  anglegroupheight      = 36;
-  anglegroupwidth       = 144;
-  basegroupwidth        = 189;
-  basegroupheight       = anglegroupheight;
-  helpbuttonwidth       = 100;
-  helpbuttonheight      = 25;
-  displaywidth          = 233;
-  displayheight         = helpbuttonheight;
-  radiobuttonwidth      = 37;
-  radiobuttonheight             = 15;
+  myxmargin 		= 9;
+  myymargin 		= 9;
+  bigbuttonwidth 	= 30;
+  bigbuttonheight 	= 23;
+  smallbuttonwidth 	= 30;
+  smallbuttonheight 	= 20;
+  anglegroupheight 	= 36;
+  anglegroupwidth 	= 144;
+  basegroupwidth 	= 189;
+  basegroupheight 	= anglegroupheight;
+  helpbuttonwidth 	= 100;
+  helpbuttonheight 	= 25;
+  displaywidth 		= 233;
+  displayheight 	= helpbuttonheight;
+  radiobuttonwidth 	= 37;
+  radiobuttonheight 		= 15;
 
   int x,y;
   key_pressed = false;
@@ -106,7 +101,7 @@ QtCalculator :: QtCalculator( Calculator *_corba, QWidget *parent, const char *n
   calc_display->setFrameStyle( QFrame::WinPanel | QFrame::Sunken );
   calc_display->setAlignment( AlignRight|AlignVCenter );
   calc_display->setGeometry( myxmargin + helpbuttonwidth + myxmargin ,
-                             myymargin , displaywidth ,displayheight );
+			     myymargin , displaywidth ,displayheight );
   calc_display->setFocus();
   calc_display->setFocusPolicy( QWidget::StrongFocus );
 
@@ -154,24 +149,24 @@ QtCalculator :: QtCalculator( Calculator *_corba, QWidget *parent, const char *n
   anglebutton[0] = new QRadioButton( angle_group );
   anglebutton[0]->setText( "&Deg" )   ;
   anglebutton[0]->setGeometry( 10,anglegroupheight/2 -2,
-                               radiobuttonwidth,radiobuttonheight);
-  anglebutton[0]->setChecked(   TRUE);
+			       radiobuttonwidth,radiobuttonheight);
+  anglebutton[0]->setChecked(	TRUE);
   accel->connectItem( accel->insertItem(Key_D + ALT), this ,
-                        SLOT(Deg_Selected()) );
+			SLOT(Deg_Selected()) );
 
   anglebutton[1] = new QRadioButton( angle_group );
   anglebutton[1]->setText( "&Rad" );
   anglebutton[1]->setGeometry( 10  + radiobuttonwidth+ 8,anglegroupheight/2 - 2,
-                               radiobuttonwidth,radiobuttonheight );
+			       radiobuttonwidth,radiobuttonheight );
   accel->connectItem( accel->insertItem(Key_R + ALT), this ,
-                        SLOT(Rad_Selected()) );
+			SLOT(Rad_Selected()) );
 
   anglebutton[2] = new QRadioButton( angle_group );
   anglebutton[2]->setText( "&Gra" );
   anglebutton[2]->setGeometry( 10 +2* radiobuttonwidth+ 16 ,anglegroupheight/2 -2,
-                               radiobuttonwidth, radiobuttonheight );
+			       radiobuttonwidth, radiobuttonheight );
   accel->connectItem( accel->insertItem(Key_G + ALT), this ,
-                        SLOT(Gra_Selected()) );
+			SLOT(Gra_Selected()) );
 
   for(u = 0;u <3;u++) anglebutton[u]->setFont(buttonfont);
 
@@ -194,31 +189,31 @@ QtCalculator :: QtCalculator( Calculator *_corba, QWidget *parent, const char *n
     basebutton[0] = new QRadioButton( base_group );
     basebutton[0]->setText( "&Hex" );
     basebutton[0]->setGeometry( 10 , basegroupheight/2 -2,
-                                radiobuttonwidth, radiobuttonheight );
+				radiobuttonwidth, radiobuttonheight );
     accel->connectItem( accel->insertItem(Key_H + ALT), this ,
-                SLOT(Hex_Selected()) );
+ 		SLOT(Hex_Selected()) );
 
     basebutton[1] = new QRadioButton( base_group );
     basebutton[1]->setText( "D&ec" );
     basebutton[1]->setGeometry( 10 + radiobuttonwidth +8 , basegroupheight/2 -2,
-                        radiobuttonwidth, radiobuttonheight );
+			radiobuttonwidth, radiobuttonheight );
     basebutton[1]->setChecked(TRUE);
     accel->connectItem( accel->insertItem(Key_E + ALT), this ,
-                        SLOT(Dec_Selected()) );
+			SLOT(Dec_Selected()) );
 
     basebutton[2] = new QRadioButton( base_group );
     basebutton[2]->setText( "&Oct" );
     basebutton[2]->setGeometry( 10 + 2*radiobuttonwidth + 16, basegroupheight/2 -2,
-                        radiobuttonwidth, radiobuttonheight );
+			radiobuttonwidth, radiobuttonheight );
     accel->connectItem( accel->insertItem(Key_O + ALT), this ,
-                        SLOT(Oct_Selected()) );
+			SLOT(Oct_Selected()) );
 
     basebutton[3] = new QRadioButton( base_group);
     basebutton[3]->setText( "&Bin" );
     basebutton[3]->setGeometry( 10 + 3*radiobuttonwidth + 24, basegroupheight/2 -2,
-                        radiobuttonwidth, radiobuttonheight );
+			radiobuttonwidth, radiobuttonheight );
     accel->connectItem( accel->insertItem(Key_B + ALT), this ,
-                        SLOT(Bin_Selected()) );
+			SLOT(Bin_Selected()) );
 
     for(u = 0;u <4;u++) basebutton[u]->setFont(buttonfont);
 
@@ -248,7 +243,7 @@ QtCalculator :: QtCalculator( Calculator *_corba, QWidget *parent, const char *n
     pbinv = new QPushButton( this, "InverseButton" );
     pbinv->setText( "Inv" );
     pbinv->setGeometry(buttonxmargin + buttonxmargin + smallbuttonwidth
-                       ,y, smallbuttonwidth,smallbuttonheight );
+		       ,y, smallbuttonwidth,smallbuttonheight );
     connect( pbinv, SIGNAL(toggled(bool)), SLOT(pbinvtoggled(bool)));
     pbinv->setToggleButton(TRUE);
     pbinv->setFont(buttonfont);
@@ -256,7 +251,7 @@ QtCalculator :: QtCalculator( Calculator *_corba, QWidget *parent, const char *n
     pbA = new QPushButton( this, "Abutton" );
     pbA->setText( "A" );
     pbA->setGeometry(buttonxmargin + buttonxmargin + buttonxmargin  + 2*smallbuttonwidth
-                     ,y, smallbuttonwidth,smallbuttonheight );
+		     ,y, smallbuttonwidth,smallbuttonheight );
     connect( pbA, SIGNAL(toggled(bool)), SLOT(pbAtoggled(bool)));
     pbA->setToggleButton(TRUE);
     pbA->setFont(buttonfont);
@@ -274,7 +269,7 @@ QtCalculator :: QtCalculator( Calculator *_corba, QWidget *parent, const char *n
     pbplusminus = new QPushButton( this, "plusminusbutton" );
     pbplusminus->setText( "+/-" );
     pbplusminus->setGeometry(buttonxmargin + buttonxmargin + smallbuttonwidth
-                             ,y, smallbuttonwidth,smallbuttonheight );
+			     ,y, smallbuttonwidth,smallbuttonheight );
     connect( pbplusminus, SIGNAL(toggled(bool)), SLOT(pbplusminustoggled(bool)));
     pbplusminus->setToggleButton(TRUE);
     pbplusminus->setFont(buttonfont);
@@ -282,7 +277,7 @@ QtCalculator :: QtCalculator( Calculator *_corba, QWidget *parent, const char *n
     pbB = new QPushButton( this, "Bbutton" );
     pbB->setText( "B" );
     pbB->setGeometry(buttonxmargin + buttonxmargin + buttonxmargin  + 2*smallbuttonwidth
-                     ,y, smallbuttonwidth,smallbuttonheight );
+		     ,y, smallbuttonwidth,smallbuttonheight );
     connect( pbB, SIGNAL(toggled(bool)), SLOT(pbBtoggled(bool)));
     pbB->setToggleButton(TRUE);
     pbB->setFont(buttonfont);
@@ -301,7 +296,7 @@ QtCalculator :: QtCalculator( Calculator *_corba, QWidget *parent, const char *n
     pbreci = new QPushButton( this, "recibutton" );
     pbreci->setText( "1/x" );
     pbreci->setGeometry(buttonxmargin + buttonxmargin + smallbuttonwidth
-                           ,y, smallbuttonwidth,smallbuttonheight );
+			   ,y, smallbuttonwidth,smallbuttonheight );
     connect( pbreci, SIGNAL(toggled(bool)), SLOT(pbrecitoggled(bool)));
     pbreci->setToggleButton(TRUE);
     pbreci->setFont(buttonfont);
@@ -309,7 +304,7 @@ QtCalculator :: QtCalculator( Calculator *_corba, QWidget *parent, const char *n
     pbC = new QPushButton( this, "Cbutton" );
     pbC->setText( "C" );
     pbC->setGeometry(buttonxmargin + buttonxmargin + buttonxmargin + 2*smallbuttonwidth
-                     ,y, smallbuttonwidth,smallbuttonheight );
+		     ,y, smallbuttonwidth,smallbuttonheight );
     connect( pbC, SIGNAL(toggled(bool)), SLOT(pbCtoggled(bool)));
     pbC->setToggleButton(TRUE);
     pbC->setFont(buttonfont);
@@ -327,7 +322,7 @@ QtCalculator :: QtCalculator( Calculator *_corba, QWidget *parent, const char *n
     pbfactorial = new QPushButton( this, "factorialbutton" );
     pbfactorial->setText( "x!" );
     pbfactorial->setGeometry(buttonxmargin + buttonxmargin + smallbuttonwidth
-                             ,y, smallbuttonwidth,smallbuttonheight );
+			     ,y, smallbuttonwidth,smallbuttonheight );
     connect( pbfactorial, SIGNAL(toggled(bool)), SLOT(pbfactorialtoggled(bool)));
     pbfactorial->setToggleButton(TRUE);
     pbfactorial->setFont(buttonfont);
@@ -336,7 +331,7 @@ QtCalculator :: QtCalculator( Calculator *_corba, QWidget *parent, const char *n
     pbD = new QPushButton( this, "Dbutton" );
     pbD->setText( "D" );
     pbD->setGeometry(buttonxmargin + buttonxmargin + buttonxmargin  + 2*smallbuttonwidth
-                     ,y, smallbuttonwidth,smallbuttonheight );
+		     ,y, smallbuttonwidth,smallbuttonheight );
     connect( pbD, SIGNAL(toggled(bool)), SLOT(pbDtoggled(bool)));
     pbD->setToggleButton(TRUE);
     pbD->setFont(buttonfont);
@@ -353,7 +348,7 @@ QtCalculator :: QtCalculator( Calculator *_corba, QWidget *parent, const char *n
     pbsquare = new QPushButton( this, "squarebutton" );
     pbsquare->setText( "x^2" );
     pbsquare->setGeometry(buttonxmargin  + buttonxmargin + smallbuttonwidth
-                          ,y, smallbuttonwidth,smallbuttonheight );
+			  ,y, smallbuttonwidth,smallbuttonheight );
     connect( pbsquare, SIGNAL(toggled(bool)), SLOT(pbsquaretoggled(bool)));
     pbsquare->setToggleButton(TRUE);
     pbsquare->setFont(buttonfont);
@@ -361,7 +356,7 @@ QtCalculator :: QtCalculator( Calculator *_corba, QWidget *parent, const char *n
     pbE = new QPushButton( this, "Ebutton" );
     pbE->setText( "E" );
     pbE->setGeometry(buttonxmargin + buttonxmargin + buttonxmargin  + 2*smallbuttonwidth
-                     ,y, smallbuttonwidth,smallbuttonheight );
+		     ,y, smallbuttonwidth,smallbuttonheight );
     connect( pbE, SIGNAL(toggled(bool)), SLOT(pbEtoggled(bool)));
     pbE->setToggleButton(TRUE);
     pbE->setFont(buttonfont);
@@ -379,7 +374,7 @@ QtCalculator :: QtCalculator( Calculator *_corba, QWidget *parent, const char *n
     pbpower = new QPushButton( this, "powerbutton" );
     pbpower->setText( "x^y" );
     pbpower->setGeometry(buttonxmargin  + buttonxmargin + smallbuttonwidth
-                     ,y, smallbuttonwidth,smallbuttonheight );
+		     ,y, smallbuttonwidth,smallbuttonheight );
     connect( pbpower, SIGNAL(toggled(bool)), SLOT(pbpowertoggled(bool)));
     pbpower->setToggleButton(TRUE);
     pbpower->setFont(buttonfont);
@@ -387,7 +382,7 @@ QtCalculator :: QtCalculator( Calculator *_corba, QWidget *parent, const char *n
     pbF = new QPushButton( this, "Fbutton" );
     pbF->setText( "F" );
     pbF->setGeometry(buttonxmargin + buttonxmargin +buttonxmargin  + 2*smallbuttonwidth
-                              ,y, smallbuttonwidth,smallbuttonheight );
+			      ,y, smallbuttonwidth,smallbuttonheight );
     connect( pbF, SIGNAL(toggled(bool)), SLOT(pbFtoggled(bool)));
     pbF->setToggleButton(TRUE);
     pbF->setFont(buttonfont);
@@ -406,7 +401,7 @@ QtCalculator :: QtCalculator( Calculator *_corba, QWidget *parent, const char *n
     pbEE = new QPushButton( this, "EEbutton" );
     pbEE->setText( "EE" );
     pbEE->setGeometry( x
-                     ,y, bigbuttonwidth,bigbuttonheight );
+		     ,y, bigbuttonwidth,bigbuttonheight );
     pbEE->setToggleButton(TRUE);
     connect( pbEE, SIGNAL(toggled(bool)), SLOT(EEtoggled(bool)));
     pbEE->setFont(buttonfont);
@@ -414,7 +409,7 @@ QtCalculator :: QtCalculator( Calculator *_corba, QWidget *parent, const char *n
     pbMR = new QPushButton( this, "MRbutton" );
     pbMR->setText( "MR" );
     pbMR->setGeometry( x + bigbuttonwidth + buttonxmargin
-                     ,y, bigbuttonwidth,bigbuttonheight );
+		     ,y, bigbuttonwidth,bigbuttonheight );
     connect( pbMR, SIGNAL(toggled(bool)), SLOT(pbMRtoggled(bool)));
     pbMR->setToggleButton(TRUE);
     pbMR->setFont(buttonfont);
@@ -422,7 +417,7 @@ QtCalculator :: QtCalculator( Calculator *_corba, QWidget *parent, const char *n
     pbMplusminus = new QPushButton( this, "Mplusminusbutton" );
     pbMplusminus->setText( "M+-" );
     pbMplusminus->setGeometry(x + 2*bigbuttonwidth + 2*buttonxmargin
-                     ,y, bigbuttonwidth,bigbuttonheight );
+		     ,y, bigbuttonwidth,bigbuttonheight );
     connect( pbMplusminus, SIGNAL(toggled(bool)), SLOT(pbMplusminustoggled(bool)));
     pbMplusminus->setToggleButton(TRUE);
     pbMplusminus->setFont(buttonfont);
@@ -430,7 +425,7 @@ QtCalculator :: QtCalculator( Calculator *_corba, QWidget *parent, const char *n
     pbMC = new QPushButton( this, "MCbutton" );
     pbMC->setText( "MC" );
     pbMC->setGeometry(x + 3*bigbuttonwidth + 3*buttonxmargin
-                     ,y, bigbuttonwidth,bigbuttonheight );
+		     ,y, bigbuttonwidth,bigbuttonheight );
     connect( pbMC, SIGNAL(toggled(bool)), SLOT(pbMCtoggled(bool)));
     pbMC->setToggleButton(TRUE);
     pbMC->setFont(buttonfont);
@@ -438,7 +433,7 @@ QtCalculator :: QtCalculator( Calculator *_corba, QWidget *parent, const char *n
     pbClear = new QPushButton( this, "Clearbutton" );
     pbClear->setText( "C" );
     pbClear->setGeometry(x + 4*bigbuttonwidth + 4* buttonxmargin
-                     ,y, bigbuttonwidth,bigbuttonheight );
+		     ,y, bigbuttonwidth,bigbuttonheight );
     connect( pbClear, SIGNAL(toggled(bool)), SLOT(pbCleartoggled(bool)));
     pbClear->setToggleButton(TRUE);
     pbClear->setFont(buttonfont);
@@ -446,7 +441,7 @@ QtCalculator :: QtCalculator( Calculator *_corba, QWidget *parent, const char *n
     pbAC = new QPushButton( this, "ACbutton" );
     pbAC->setText( "AC" );
     pbAC->setGeometry(x + 5 * bigbuttonwidth + 5 * buttonxmargin
-                     ,y, bigbuttonwidth,bigbuttonheight );
+		     ,y, bigbuttonwidth,bigbuttonheight );
     connect( pbAC, SIGNAL(toggled(bool)), SLOT(pbACtoggled(bool)));
     pbAC->setToggleButton(TRUE);
     pbAC->setFont(buttonfont);
@@ -462,7 +457,7 @@ QtCalculator :: QtCalculator( Calculator *_corba, QWidget *parent, const char *n
     pb7 = new QPushButton( this, "7button" );
     pb7->setText( "7" );
     pb7->setGeometry(x
-                     ,y, bigbuttonwidth,bigbuttonheight );
+		     ,y, bigbuttonwidth,bigbuttonheight );
     connect( pb7, SIGNAL(toggled(bool)), SLOT(pb7toggled(bool)));
     pb7->setToggleButton(TRUE);
     pb7->setFont(buttonfont);
@@ -470,7 +465,7 @@ QtCalculator :: QtCalculator( Calculator *_corba, QWidget *parent, const char *n
     pb8 = new QPushButton( this, "8button" );
     pb8->setText( "8" );
     pb8->setGeometry(x + bigbuttonwidth + buttonxmargin
-                     ,y, bigbuttonwidth,bigbuttonheight );
+		     ,y, bigbuttonwidth,bigbuttonheight );
     connect( pb8, SIGNAL(toggled(bool)), SLOT(pb8toggled(bool)));
     pb8->setToggleButton(TRUE);
     pb8->setFont(buttonfont);
@@ -478,7 +473,7 @@ QtCalculator :: QtCalculator( Calculator *_corba, QWidget *parent, const char *n
     pb9 = new QPushButton( this, "9button" );
     pb9->setText( "9" );
     pb9->setGeometry(x + 2*bigbuttonwidth + 2 * buttonxmargin
-                     ,y, bigbuttonwidth,bigbuttonheight );
+		     ,y, bigbuttonwidth,bigbuttonheight );
     connect( pb9, SIGNAL(toggled(bool)), SLOT(pb9toggled(bool)));
     pb9->setToggleButton(TRUE);
     pb9->setFont(buttonfont);
@@ -486,7 +481,7 @@ QtCalculator :: QtCalculator( Calculator *_corba, QWidget *parent, const char *n
     pbparenopen = new QPushButton( this, "parenopenbutton" );
     pbparenopen->setText( "(" );
     pbparenopen->setGeometry(x + 3 * bigbuttonwidth + 3 * buttonxmargin
-                     ,y, bigbuttonwidth,bigbuttonheight );
+		     ,y, bigbuttonwidth,bigbuttonheight );
     connect( pbparenopen, SIGNAL(toggled(bool)), SLOT(pbparenopentoggled(bool)));
     pbparenopen->setToggleButton(TRUE);
     pbparenopen->setFont(buttonfont);
@@ -494,7 +489,7 @@ QtCalculator :: QtCalculator( Calculator *_corba, QWidget *parent, const char *n
     pbparenclose = new QPushButton( this, "parenclosebutton" );
     pbparenclose->setText( ")" );
     pbparenclose->setGeometry(x + 4* bigbuttonwidth + 4 * buttonxmargin
-                     ,y, bigbuttonwidth,bigbuttonheight );
+		     ,y, bigbuttonwidth,bigbuttonheight );
     connect( pbparenclose, SIGNAL(toggled(bool)), SLOT(pbparenclosetoggled(bool)));
     pbparenclose->setToggleButton(TRUE);
     pbparenclose->setFont(buttonfont);
@@ -502,7 +497,7 @@ QtCalculator :: QtCalculator( Calculator *_corba, QWidget *parent, const char *n
     pband = new QPushButton( this, "andbutton" );
     pband->setText( "And" );
     pband->setGeometry(x + 5 * bigbuttonwidth + 5 * buttonxmargin
-                     ,y, bigbuttonwidth,bigbuttonheight );
+		     ,y, bigbuttonwidth,bigbuttonheight );
     connect( pband, SIGNAL(toggled(bool)), SLOT(pbandtoggled(bool)));
     pband->setToggleButton(TRUE);
     pband->setFont(buttonfont);
@@ -518,7 +513,7 @@ QtCalculator :: QtCalculator( Calculator *_corba, QWidget *parent, const char *n
     pb4 = new QPushButton( this, "4button" );
     pb4->setText( "4" );
     pb4->setGeometry(x
-                     ,y, bigbuttonwidth,bigbuttonheight );
+		     ,y, bigbuttonwidth,bigbuttonheight );
     connect( pb4, SIGNAL(toggled(bool)), SLOT(pb4toggled(bool)));
     pb4->setToggleButton(TRUE);
     pb4->setFont(buttonfont);
@@ -526,7 +521,7 @@ QtCalculator :: QtCalculator( Calculator *_corba, QWidget *parent, const char *n
     pb5 = new QPushButton( this, "5button" );
     pb5->setText( "5" );
     pb5->setGeometry(x + bigbuttonwidth + buttonxmargin
-                     ,y, bigbuttonwidth,bigbuttonheight );
+		     ,y, bigbuttonwidth,bigbuttonheight );
     connect( pb5, SIGNAL(toggled(bool)), SLOT(pb5toggled(bool)));
     pb5->setToggleButton(TRUE);
     pb5->setFont(buttonfont);
@@ -534,7 +529,7 @@ QtCalculator :: QtCalculator( Calculator *_corba, QWidget *parent, const char *n
     pb6 = new QPushButton( this, "6button" );
     pb6->setText( "6" );
     pb6->setGeometry(x + 2*bigbuttonwidth + 2*buttonxmargin
-                     ,y, bigbuttonwidth,bigbuttonheight );
+		     ,y, bigbuttonwidth,bigbuttonheight );
     connect( pb6, SIGNAL(toggled(bool)), SLOT(pb6toggled(bool)));
     pb6->setToggleButton(TRUE);
     pb6->setFont(buttonfont);
@@ -542,7 +537,7 @@ QtCalculator :: QtCalculator( Calculator *_corba, QWidget *parent, const char *n
     pbX = new QPushButton( this, "Multiplybutton" );
     pbX->setText( "X" );
     pbX->setGeometry(x + 3*bigbuttonwidth + 3*buttonxmargin
-                     ,y, bigbuttonwidth,bigbuttonheight );
+		     ,y, bigbuttonwidth,bigbuttonheight );
     connect( pbX, SIGNAL(toggled(bool)), SLOT(pbXtoggled(bool)));
     pbX->setToggleButton(TRUE);
     pbX->setFont(buttonfont);
@@ -550,7 +545,7 @@ QtCalculator :: QtCalculator( Calculator *_corba, QWidget *parent, const char *n
     pbdivision = new QPushButton( this, "divisionbutton" );
     pbdivision->setText( "/" );
     pbdivision->setGeometry(x + 4*bigbuttonwidth + 4 * buttonxmargin
-                     ,y, bigbuttonwidth,bigbuttonheight );
+		     ,y, bigbuttonwidth,bigbuttonheight );
     connect( pbdivision, SIGNAL(toggled(bool)), SLOT(pbdivisiontoggled(bool)));
     pbdivision->setToggleButton(TRUE);
     pbdivision->setFont(buttonfont);
@@ -558,7 +553,7 @@ QtCalculator :: QtCalculator( Calculator *_corba, QWidget *parent, const char *n
     pbor = new QPushButton( this, "orbutton" );
     pbor->setText( "Or" );
     pbor->setGeometry(x + 5 * bigbuttonwidth + 5 *buttonxmargin
-                     ,y, bigbuttonwidth,bigbuttonheight );
+		     ,y, bigbuttonwidth,bigbuttonheight );
     connect( pbor, SIGNAL(toggled(bool)), SLOT(pbortoggled(bool)));
     pbor->setToggleButton(TRUE);
     pbor->setFont(buttonfont);
@@ -574,25 +569,25 @@ QtCalculator :: QtCalculator( Calculator *_corba, QWidget *parent, const char *n
     pb1 = new QPushButton( this, "1button" );
     pb1->setText( "1" );
     pb1->setGeometry(x
-                     ,y, bigbuttonwidth,bigbuttonheight );
+		     ,y, bigbuttonwidth,bigbuttonheight );
     //connect( pb1, SIGNAL(clicked()), SLOT(button1()) );
     connect( pb1, SIGNAL(toggled(bool)), SLOT(pb1toggled(bool)));
-    pb1->setToggleButton(TRUE);
+    pb1->setToggleButton(TRUE);	
     pb1->setFont(buttonfont);
 
     pb2 = new QPushButton( this, "2button" );
     pb2->setText( "2" );
     pb2->setGeometry(x + bigbuttonwidth + buttonxmargin
-                     ,y, bigbuttonwidth,bigbuttonheight );
+		     ,y, bigbuttonwidth,bigbuttonheight );
 
     connect( pb2, SIGNAL(toggled(bool)), SLOT(pb2toggled(bool)));
-    pb2->setToggleButton(TRUE);
+    pb2->setToggleButton(TRUE);		
     pb2->setFont(buttonfont);
 
     pb3 = new QPushButton( this, "3button" );
     pb3->setText( "3" );
     pb3->setGeometry(x + 2* bigbuttonwidth + 2* buttonxmargin
-                     ,y, bigbuttonwidth,bigbuttonheight );
+		     ,y, bigbuttonwidth,bigbuttonheight );
     connect( pb3, SIGNAL(toggled(bool)), SLOT(pb3toggled(bool)));
     pb3->setToggleButton(TRUE);
     pb3->setFont(buttonfont);
@@ -600,7 +595,7 @@ QtCalculator :: QtCalculator( Calculator *_corba, QWidget *parent, const char *n
     pbplus = new QPushButton( this, "plusbutton" );
     pbplus->setText( "+" );
     pbplus->setGeometry(x + 3* bigbuttonwidth + 3* buttonxmargin
-                     ,y, bigbuttonwidth,bigbuttonheight );
+		     ,y, bigbuttonwidth,bigbuttonheight );
     connect( pbplus, SIGNAL(toggled(bool)), SLOT(pbplustoggled(bool)));
     pbplus->setToggleButton(TRUE);
     pbplus->setFont(buttonfont);
@@ -609,7 +604,7 @@ QtCalculator :: QtCalculator( Calculator *_corba, QWidget *parent, const char *n
     pbminus = new QPushButton( this, "minusbutton" );
     pbminus->setText( "-" );
     pbminus->setGeometry(x + 4* bigbuttonwidth + 4* buttonxmargin
-                     ,y, bigbuttonwidth,bigbuttonheight );
+		     ,y, bigbuttonwidth,bigbuttonheight );
     connect( pbminus, SIGNAL(toggled(bool)), SLOT(pbminustoggled(bool)));
     pbminus->setToggleButton(TRUE);
     pbminus->setFont(buttonfont);
@@ -617,7 +612,7 @@ QtCalculator :: QtCalculator( Calculator *_corba, QWidget *parent, const char *n
     pbshift = new QPushButton( this, "shiftbutton" );
     pbshift->setText( "Lsh" );
     pbshift->setGeometry(x + 5* bigbuttonwidth + 5* buttonxmargin
-                     ,y, bigbuttonwidth,bigbuttonheight );
+		     ,y, bigbuttonwidth,bigbuttonheight );
     connect( pbshift, SIGNAL(toggled(bool)), SLOT(pbshifttoggled(bool)));
     pbshift->setToggleButton(TRUE);
     pbshift->setFont(buttonfont);
@@ -632,7 +627,7 @@ QtCalculator :: QtCalculator( Calculator *_corba, QWidget *parent, const char *n
     pbperiod = new QPushButton( this, "periodbutton" );
     pbperiod->setText( "." );
     pbperiod->setGeometry(x
-                     ,y, bigbuttonwidth,bigbuttonheight );
+		     ,y, bigbuttonwidth,bigbuttonheight );
     connect( pbperiod, SIGNAL(toggled(bool)), SLOT(pbperiodtoggled(bool)));
     pbperiod->setToggleButton(TRUE);
     pbperiod->setFont(buttonfont);
@@ -640,7 +635,7 @@ QtCalculator :: QtCalculator( Calculator *_corba, QWidget *parent, const char *n
     pb0 = new QPushButton( this, "0button" );
     pb0->setText( "0" );
     pb0->setGeometry(x + 1* bigbuttonwidth + 1* buttonxmargin
-                     ,y, bigbuttonwidth,bigbuttonheight );
+		     ,y, bigbuttonwidth,bigbuttonheight );
     connect( pb0, SIGNAL(toggled(bool)), SLOT(pb0toggled(bool)));
     pb0->setToggleButton(TRUE);
     pb0->setFont(buttonfont);
@@ -648,7 +643,7 @@ QtCalculator :: QtCalculator( Calculator *_corba, QWidget *parent, const char *n
     pbequal = new QPushButton( this, "equalbutton" );
     pbequal->setText( "=" );
     pbequal->setGeometry(x + 2* bigbuttonwidth + 2* buttonxmargin
-                     ,y, bigbuttonwidth,bigbuttonheight );
+		     ,y, bigbuttonwidth,bigbuttonheight );
     connect( pbequal, SIGNAL(toggled(bool)), SLOT(pbequaltoggled(bool)));
     pbequal->setToggleButton(TRUE);
     pbequal->setFont(buttonfont);
@@ -656,7 +651,7 @@ QtCalculator :: QtCalculator( Calculator *_corba, QWidget *parent, const char *n
     pbpercent = new QPushButton( this, "percentbutton" );
     pbpercent->setText( "%" );
     pbpercent->setGeometry(x + 3* bigbuttonwidth + 3* buttonxmargin
-                     ,y, bigbuttonwidth,bigbuttonheight );
+		     ,y, bigbuttonwidth,bigbuttonheight );
     connect( pbpercent, SIGNAL(toggled(bool)), SLOT(pbpercenttoggled(bool)));
     pbpercent->setToggleButton(TRUE);
     pbpercent->setFont(buttonfont);
@@ -665,7 +660,7 @@ QtCalculator :: QtCalculator( Calculator *_corba, QWidget *parent, const char *n
     pbnegate = new QPushButton( this, "OneComplementbutton" );
     pbnegate->setText( "Cmp" );
     pbnegate->setGeometry(x  + 4* bigbuttonwidth + 4* buttonxmargin
-                              ,y, bigbuttonwidth, bigbuttonheight );
+			      ,y, bigbuttonwidth, bigbuttonheight );
     connect( pbnegate, SIGNAL(toggled(bool)), SLOT(pbnegatetoggled(bool)));
     pbnegate->setToggleButton(TRUE);
     pbnegate->setFont(buttonfont);
@@ -673,7 +668,7 @@ QtCalculator :: QtCalculator( Calculator *_corba, QWidget *parent, const char *n
     pbmod = new QPushButton( this, "modbutton" );
     pbmod->setText( "Mod" );
     pbmod->setGeometry(x + 5* bigbuttonwidth + 5* buttonxmargin
-                     ,y, bigbuttonwidth,bigbuttonheight );
+		     ,y, bigbuttonwidth,bigbuttonheight );
     connect( pbmod, SIGNAL(toggled(bool)), SLOT(pbmodtoggled(bool)));
     pbmod->setToggleButton(TRUE);
     pbmod->setFont(buttonfont);
@@ -768,6 +763,9 @@ void QtCalculator::Gra_Selected()
 
 
 void QtCalculator::helpclicked(){
+
+    // kapp->invokeHTMLHelp("","");
+
 }
 
 void QtCalculator::keyPressEvent( QKeyEvent *e ){
@@ -1252,7 +1250,7 @@ void QtCalculator::pbMRtoggled(bool myboolean){
     pbMR->setOn(FALSE);
 }
 
-void QtCalculator::pbAtoggled(bool myboolean){
+void QtCalculator::pbAtoggled(bool myboolean){	
   if(myboolean)
     buttonA();
     if(pbA->isOn() && (!key_pressed))
@@ -1525,22 +1523,21 @@ void QtCalculator::configclicked(){
   tabdialog = new QTabDialog(0,"tabdialog",TRUE);
 
   tabdialog->setCaption( i18n("KCalc Configuraton") );
-  tabdialog->resize( 360, 390 );
+  tabdialog->resize( 350, 350 );
   tabdialog->setCancelButton( i18n("Cancel") );
 
   QWidget *about = new QWidget(tabdialog,"about");
-  QVBoxLayout *lay1 = new QVBoxLayout( about );
-  lay1->setMargin( 5 );
-  lay1->setSpacing( 10 );
 
   QGroupBox *box = new QGroupBox(about,"box");
-  QGridLayout *grid1 = new QGridLayout(box,2,2,15,7);
   QLabel  *label = new QLabel(box,"label");
   QLabel  *label2 = new QLabel(box,"label2");
+  box->setGeometry(10,10,320,260);
 
   box->setTitle(i18n("About"));
-  grid1->addWidget(label,0,1);
-  grid1->addMultiCellWidget(label2,2,2,0,1);
+
+
+  label->setGeometry(140,30,160,170);
+  label2->setGeometry(20,150,280,100);
 
   QString labelstring = "KCalc "KCALCVERSION"\n"\
     "Bernd Johannes Wuebben\n"\
@@ -1551,29 +1548,28 @@ void QtCalculator::configclicked(){
 
   QString labelstring2 =
 #ifdef HAVE_LONG_DOUBLE
-                i18n( "Base type: long double\n");
+		i18n( "Base type: long double\n");
 #else
-                i18n( "Due to broken glibc's everywhere, "\
-                      "I had to reduce KCalc's precision from 'long double' "\
-                      "to 'double'. "\
-                      "Owners of systems with a working libc "\
-                      "should recompile KCalc with 'long double' precision "\
-                      "enabled. See the README for details.");
+		i18n( "Due to broken glibc's everywhere, "\
+		      "I had to reduce KCalc's precision from 'long double' "\
+		      "to 'double'. "\
+		      "Owners of systems with a working libc "\
+		      "should recompile KCalc with 'long double' precision "\
+		      "enabled. See the README for details.");
 #endif
 
   label->setAlignment(AlignLeft|WordBreak|ExpandTabs);
-  label->setText(labelstring);
+  label->setText(labelstring.data());
 
   label2->setAlignment(AlignLeft|WordBreak|ExpandTabs);
-  label2->setText(labelstring2);
+  label2->setText(labelstring2.data());
 
   // HACK
   // QPixmap pm( BarIcon( "kcalclogo" ) );
   QPixmap pm;
   QLabel *logo = new QLabel(box);
   logo->setPixmap(pm);
-  grid1->addWidget(logo,0,0);
-  lay1->addWidget(box);
+  logo->setGeometry(30, 20, pm.width(), pm.height());
 
 
   DefStruct newdefstruct;
@@ -1680,7 +1676,7 @@ void QtCalculator::readSettings()
   config->setGroup( "Font" );
 
   kcalcdefaults.font = config->readFontEntry("Font",
-        new QFont("helvetica",16,QFont::Bold));
+	new QFont("helvetica",16,QFont::Bold));
 
   config->setGroup("Colors");
   QColor tmpC(189, 255, 222);
@@ -1709,7 +1705,7 @@ void QtCalculator::readSettings()
 void QtCalculator::writeSettings()
 {
     /*
-  KConfig *config = kapp->config();
+  KConfig *config = kapp->config();		
 
   config->setGroup( "Font" );
   config->writeEntry("Font",kcalcdefaults.font);
@@ -1754,7 +1750,7 @@ void QtCalculator::display_selected(){
     QClipboard *cb = QApplication::clipboard();
 
     CALCAMNT result;
-    result = (CALCAMNT) cb->text().toDouble();
+    result = (CALCAMNT) strtod( cb->text(),0);
     //    printf("%Lg\n",result);
     last_input = PASTE;
     DISPLAY_AMOUNT = result;
@@ -1827,12 +1823,12 @@ void QtCalculator::set_colors(){
 
   QColorGroup cgrp = mypalette.normal();
   QColorGroup ncgrp(kcalcdefaults.forecolor,
-                    cgrp.background(),
-                    cgrp.light(),
-                    cgrp.dark(),
-                    cgrp.mid(),
-                    kcalcdefaults.forecolor,
-                    kcalcdefaults.backcolor);
+		    cgrp.background(),
+		    cgrp.light(),
+		    cgrp.dark(),
+		    cgrp.mid(),
+		    kcalcdefaults.forecolor,
+		    kcalcdefaults.backcolor);
 
   mypalette.setNormal(ncgrp);
   mypalette.setDisabled(ncgrp);
@@ -1859,14 +1855,14 @@ void QtCalculator::temp_stack_next(){
   CALCAMNT *number;
 
   if( temp_stack.current() == temp_stack.getLast()){
-        KNotifyClient::beep();
-        return;
+        QApplication::beep();
+	return;
   }
 
   number = temp_stack.next();
 
   if(number == NULL){
-       KNotifyClient::beep();
+       QApplication::beep();
     return;
   }
   else{
@@ -1885,14 +1881,14 @@ void QtCalculator::temp_stack_prev(){
   CALCAMNT *number;
 
   if( temp_stack.current() == temp_stack.getFirst()){
-        KNotifyClient::beep();
-        return;
+        QApplication::beep();
+	return;
   }
 
   number = temp_stack.prev();
 
   if(number == NULL){
-    KNotifyClient::beep();
+    QApplication::beep();
     return;
   }
   else{
