@@ -20,13 +20,19 @@
 #include "main.h"
 #include "kcalc.h"
 #include "kspread_view.h"
+#include "kspread_table.h"
 #include "kspread_events.h"
+#include "kspread_cell.h"
 #include "kspread_doc.h"
 #include "kspread_util.h"
 #include "kspread_map.h"
 
+#include <qmessagebox.h>
+#include <qstring.h>
 
-#include <kdebug.h>
+#include <kaction.h>
+#include <kinstance.h>
+#include <kiconloader.h>
 
 #include <stdio.h>
 
@@ -40,9 +46,9 @@ extern "C"
 {
     void* init_libkspreadcalc()
     {
-        return new CalcFactory;
+	return new CalcFactory;
     }
-}
+};
 
 KInstance* CalcFactory::s_global = 0;
 
@@ -54,19 +60,17 @@ CalcFactory::CalcFactory( QObject* parent, const char* name )
 
 CalcFactory::~CalcFactory()
 {
-    delete s_global;
 }
 
-QObject* CalcFactory::createObject( QObject* parent, const char* name, const char* /*classname*/, const QStringList & )
+QObject* CalcFactory::create( QObject* parent, const char* name, const char* /*classname*/, const QStringList & )
 {
     if ( !parent->inherits("KSpreadView") )
     {
-        kdError() << "CalcFactory: KSpreadView expected. Parent is " << parent->className() << endl;
-        return 0;
+	qDebug("CalcFactory: KSpreadView expected.");
+	return 0;
     }
 
-    QObject *obj = new Calculator( (KSpreadView*)parent, name );
-    return obj;
+    return new Calculator( (KSpreadView*)parent, name );
 }
 
 KInstance* CalcFactory::global()
@@ -81,25 +85,25 @@ KInstance* CalcFactory::global()
  ***************************************************/
 
 Calculator::Calculator( KSpreadView* parent, const char* name )
-    : KParts::Plugin( parent, name )
+    : Plugin( parent, name )
 {
     m_calc = 0;
     m_view = parent;
 
-    KGlobal::locale()->insertCatalogue("kspreadcalc_calc"); 
     parent->installEventFilter( this );
 
-    (void)new KAction( i18n("Calculator"), SmallIcon("kcalc", CalcFactory::global()),
-                       0, this, SLOT( showCalculator() ), actionCollection(), "kspreadcalc");
+    (void)new KAction( tr("Calculator"), 
+		       CalcFactory::global()->iconLoader()->loadApplicationIcon( "kspreadcalc.png", KIconLoader::Small ),
+		       0, this, SLOT( showCalculator() ), actionCollection(), "kspreadcalc");
 }
 
 void Calculator::showCalculator()
 {
     if ( m_calc )
     {
-        m_calc->show();
-        m_calc->raise();
-        return;
+	m_calc->show();
+	m_calc->raise();
+	return;
     }
 
      m_calc = new QtCalculator( this, (KSpreadView*)parent() );
@@ -115,44 +119,37 @@ Calculator::~Calculator()
 bool Calculator::eventFilter( QObject*, QEvent* ev )
 {
     if ( !m_calc )
-        return FALSE;
+	return FALSE;
 
     if ( KSpreadSelectionChanged::test( ev ) )
     {
-        KSpreadSelectionChanged* event = (KSpreadSelectionChanged*)ev;
+	KSpreadSelectionChanged* event = (KSpreadSelectionChanged*)ev;
+	
+	if ( event->rect().left() == 0 )
+	    return FALSE;
 
-        // Selection cleared ?
-        if ( event->rect().left() == 0 )
-            return FALSE;
+	KSpreadTable* table = m_view->doc()->map()->findTable( event->table() );
+	if ( !table )
+	    return FALSE;
 
-        KSpreadTable* table = m_view->doc()->map()->findTable( event->table() );
-        if ( !table )
-            return FALSE;
-
-        // A single cell selected ?
-        if ( event->rect().left() == event->rect().right() &&
-             event->rect().top() == event->rect().bottom() )
+	if ( event->rect().left() == event->rect().right() &&
+	     event->rect().top() == event->rect().bottom() )
         {
-            KSpreadCell* cell = table->cellAt( event->rect().left(), event->rect().top(), false );
-            if ( !cell )
-                return FALSE;
+	    KSpreadCell* cell = table->cellAt( event->rect().left(), event->rect().top() );
+	    if ( !cell )
+		return FALSE;
+	
+	    double d = cell->valueDouble();
+	    m_calc->setValue( d );
 
-            double d;
-            if ( cell->isEmpty() )
-                d = 0;
-            else
-                d = cell->value().asFloat();
-            m_calc->setValue( d );
+	    return FALSE;
+	}
 
-            return FALSE;
-        }
-
-        // Multiple cells selected ?
-        m_calc->setData( event->rect(), event->table().latin1() );
-        QString str = util_rangeName( table, event->rect() );
-        m_calc->setLabel( str.latin1() );
-
-        return FALSE;
+	m_calc->setData( event->rect(), event->table() );
+	QString str = util_rangeName( table, event->rect() );
+	m_calc->setLabel( str );
+	
+	return FALSE;
     }
 
     return FALSE;
@@ -174,26 +171,26 @@ void QtCalculator::useData()
 
     // How many cells ?
     int len = ( table_range.right() - table_range.left() + 1 ) *
-              ( table_range.bottom() - table_range.top() + 1 );
+	      ( table_range.bottom() - table_range.top() + 1 );
 
     double *v = new double[ len ];
     int n = 0;
     for( int x = table_range.left(); x <= table_range.right(); x++ )
-        for( int y = table_range.top(); y <= table_range.bottom(); y++ )
+	for( int y = table_range.top(); y <= table_range.bottom(); y++ )
         {
-            KSpreadView* view = corba->view();
-            KSpreadTable* table = view->doc()->map()->findTable( table_name );
-            if ( !table )
-                return;
-            KSpreadCell* cell = table->cellAt( x, y, false );
-            if ( !cell )
-                return;
+	    KSpreadView* view = corba->view();
+	    KSpreadTable* table = view->doc()->map()->findTable( table_name );
+	    if ( !table )
+		return;
+	    KSpreadCell* cell = table->cellAt( x, y );
+	    if ( !cell )
+		return;
 
-            v[n++] = cell->value().asFloat();
-        }
+	    v[n++] = cell->valueDouble();
+	}
 
     for( int i = 0; i < n; i++ )
-        stats.enterData( v[i] );
+	stats.enterData( v[i] );
 
     delete []v;
 
