@@ -20,41 +20,38 @@
 #ifndef footnotedia_h
 #define footnotedia_h
 
-#include <kdialogbase.h>
-#include "defs.h" // for NoteType
-#include "kwvariable.h"
-class QRadioButton;
-class QLineEdit;
-class KWDocument;
+#include <stdlib.h>
+
+#include <qtabdialog.h>
+
+class KWordDocument;
+class KWPage;
+class QWidget;
+
 /******************************************************************/
 /* Class: KWFootNoteDia                                           */
 /******************************************************************/
 
-class KWFootNoteDia : public KDialogBase
+class KWFootNoteDia : public QTabDialog
 {
     Q_OBJECT
 
 public:
-    KWFootNoteDia( NoteType _noteType, KWFootNoteVariable::Numbering _numberingType,  const QString & _manualString, QWidget *parent, KWDocument *_doc, const char *name = 0 );
+    KWFootNoteDia( QWidget *parent, const char *name, KWordDocument *_doc, KWPage *_page, int _start );
 
-    NoteType noteType() const;
-    KWFootNoteVariable::Numbering numberingType()const;
-    QString manualString()const;
 protected:
-    bool insertFootNote();
+    void setupTab1();
+    void closeEvent( QCloseEvent * ) { emit cancelButtonPressed(); }
+
+    QWidget *tab1;
+
+    KWordDocument *doc;
+    KWPage *page;
+    int start;
+
 protected slots:
-    void footLineChanged( const QString & );
-    void footNoteTypeChanged();
-    void slotConfigurate();
-private:
+    void insertFootNote();
 
-    QRadioButton *m_rbAuto;
-    QRadioButton *m_rbManual;
-
-    QRadioButton *m_rbFootNote;
-    QRadioButton *m_rbEndNote;
-    QLineEdit *m_footLine;
-    KWDocument *m_doc;
 };
 
 #endif
