@@ -17,26 +17,24 @@
    Boston, MA 02111-1307, USA.
 */
 
-#include <koApplication.h>
-#include <kcmdlineargs.h>
-#include <dcopclient.h>
-#include "kwaboutdata.h"
+#include "kword_doc.h"
+#include "kword_shell.h"
 
-static const KCmdLineOptions options[]=
+#include <koApplication.h>
+
+extern "C"
 {
-	{"+[file]", I18N_NOOP("File to open"),0},
-	KCmdLineLastOption
-};
+    void* init_libkword();
+}
 
 int main( int argc, char **argv )
 {
-    KCmdLineArgs::init( argc, argv, newKWordAboutData());
-    KCmdLineArgs::addCmdLineOptions( options );
+    KoApplication app( argc, argv, "kword", "application/x-kword" );
 
-    KoApplication app;
+    init_libkword();
+
+    app.start();
 
-    if (!app.start())
-	return 1;
     app.exec();
 
     return 0;
